@@ -88,17 +88,20 @@ int32_t CmEventRT::Destroy( CmEventRT* &event )
 CmEventRT::CmEventRT(uint32_t index, CmQueueRT *queue, CmTaskInternal *task, int32_t taskDriverId, CmDeviceRT *device, bool isVisible):
     m_index( index ),
     m_taskDriverId( taskDriverId ),
+    m_osData(nullptr),
     m_status( CM_STATUS_QUEUED ),
     m_time( 0 ),
     m_ticks(0),
+    m_hwStartTimeStampInTicks( 0 ),
+    m_hwEndTimeStampInTicks( 0 ),
     m_device( device ),
     m_queue (queue),
     m_refCount(0),
     m_isVisible(isVisible),
     m_task(task),
-    m_osData(nullptr),
     m_callbackFunction(nullptr),
-    m_callbackUserData(nullptr)
+    m_callbackUserData(nullptr),
+    m_osSignalTriggered(false)
 {
     m_globalSubmitTimeCpu.QuadPart = 0;
     m_submitTimeGpu.QuadPart = 0;
@@ -200,30 +203,6 @@ int32_t CmEventRT::Initialize(void)
     return CM_SUCCESS;
 }
 
-//*-----------------------------------------------------------------------------
-//! Query the status of the task associated with the event
-//! An event is generated when a task ( one kernel or multiples kernels running concurrently )
-//! is enqueued.
-//! This is a non-blocking call.
-//! INPUT:
-//!     The reference to status. For now only two status, CM_STATUS_QUEUED and CM_STATUS_FINISHED, are supported
-//! OUTPUT:
-//!     CM_SUCCESS if the status is successfully returned;
-//!     CM_FAILURE if not.
-//*-----------------------------------------------------------------------------
-CM_RT_API int32_t CmEventRT::GetStatus( CM_STATUS& status)
-{
-    if( ( m_status == CM_STATUS_FLUSHED ) || ( m_status == CM_STATUS_STARTED ) )
-    {
-        Query();
-    }
-
-    m_queue->FlushTaskWithoutSync();
-
-    status = m_status;
-    return CM_SUCCESS;
-}
-
 int32_t CmEventRT::GetStatusNoFlush(CM_STATUS& status)
 {
     if ((m_status == CM_STATUS_FLUSHED) || (m_status == CM_STATUS_STARTED))
@@ -250,6 +229,16 @@ int32_t CmEventRT::GetStatusNoFlush(CM_STATUS& status)
     return CM_SUCCESS;
 }
 
+int32_t CmEventRT::ModifyStatus(CM_STATUS status, uint64_t elapsedTime)
+{
+    if (m_ticks == 0)
+    {
+        m_time = elapsedTime;
+    }
+    m_status = status;
+    return CM_SUCCESS;
+}
+
 int32_t CmEventRT::GetQueue(CmQueueRT *& queue)
 {
     queue = m_queue;
@@ -559,6 +548,8 @@ int32_t CmEventRT::Query( void )
 
         m_time = param.taskDurationNs;
         m_ticks = param.taskDurationTicks;
+        m_hwStartTimeStampInTicks = param.taskHWStartTimeStampInTicks;
+        m_hwEndTimeStampInTicks = param.taskHWEndTimeStampInTicks;
         m_status = CM_STATUS_FINISHED;
 
         //Update the state tracking array when a task is finished
@@ -582,6 +573,7 @@ int32_t CmEventRT::Query( void )
         m_hwStartTimeStamp = param.taskHWStartTimeStamp;
         m_hwEndTimeStamp = param.taskHWEndTimeStamp;
 
+        EVENT_LOG(this);
     }
     else if( param.status == CM_TASK_IN_PROGRESS )
     {
@@ -596,6 +588,15 @@ finish:
     return hr;
 }
 
+//*-----------------------------------------------------------------------------
+//| Purpose:    Get m_status.
+//| Returns:    return m_status.
+//*-----------------------------------------------------------------------------
+CM_STATUS CmEventRT::GetStatusWithoutFlush()
+{
+    return m_status;
+}
+
 //*-----------------------------------------------------------------------------
 //| Purpose:    GT-PIN : Get Surface Details
 //| Returns:    result of operation
@@ -806,4 +807,32 @@ int32_t CmEventRT:: SetCallBack(EventCallBackFunction function, void  *userData)
     m_callbackUserData = userData;
     return CM_SUCCESS;
 }
+
+#if CM_LOG_ON
+std::string CmEventRT::Log(const char *callerFuncName)
+{
+    static const char *statusStrings[] = {
+#define ENUM_STRING(e)  #e
+            ENUM_STRING(CM_STATUS_QUEUED),
+            ENUM_STRING(CM_STATUS_FLUSHED),
+            ENUM_STRING(CM_STATUS_FINISHED),
+            ENUM_STRING(CM_STATUS_STARTED),
+            ENUM_STRING(CM_STATUS_RESET),
+#undef ENUM_STRING
+    };
+
+    std::ostringstream  oss;
+    oss << callerFuncName << "():\n"
+        << "<CmEvent>:" << reinterpret_cast<uint64_t>(this) << "\n"
+        << " Status: " << statusStrings[m_status] << "\n"
+        << " Duration:" << m_time << "ns\n"
+        << " DurationInTick:" << m_ticks << "\n"
+        << " StartTimeInTick:" << m_hwStartTimeStampInTicks << "\n"
+        << " EndTimeInTick:"<< m_hwEndTimeStampInTicks << "\n"
+        << " Kernel Cnt:"<< m_kernelCount << std::endl;
+
+    return oss.str();
+}
+#endif
+
 }
