@@ -287,7 +287,10 @@ CmTaskInternal::~CmTaskInternal( void )
         CmEvent *eventBase = m_taskEvent;
         CmQueueRT *cmQueue = nullptr;
         m_taskEvent->GetQueue(cmQueue);
-        cmQueue->DestroyEvent(eventBase); // need to update the m_EventArray
+        if (cmQueue)
+        {
+            cmQueue->DestroyEvent(eventBase); // need to update the m_EventArray
+        }
     }
 
     if(m_threadCoordinates){
@@ -1792,6 +1795,7 @@ int32_t CmTaskInternal::UpdateSurfaceStateOnTaskCreation()
     void **  curTaskSurfResArray = nullptr;
     uint32_t  refSurfCnt = 0;
     uint32_t *refSurfHandleArray = nullptr;
+    CM_RETURN_CODE hr = CM_SUCCESS;
 
     curTaskSurfResArray = (void **)MOS_AllocAndZeroMemory(sizeof(void *)*poolSize);
     CM_CHK_NULL_RETURN_CMERROR(curTaskSurfResArray);
@@ -1801,6 +1805,11 @@ int32_t CmTaskInternal::UpdateSurfaceStateOnTaskCreation()
     if (surfaceLock == nullptr)
     {
         CM_ASSERTMESSAGE("Error: Pointer to surface creation lock is null.");
+        if (curTaskSurfResArray)
+        {
+            MOS_FreeMemory(curTaskSurfResArray);
+            curTaskSurfResArray = nullptr;
+        }
         return CM_NULL_POINTER;
     }
 
@@ -1808,9 +1817,10 @@ int32_t CmTaskInternal::UpdateSurfaceStateOnTaskCreation()
 
     // get the last tracker
     PCM_CONTEXT_DATA cmData = ( PCM_CONTEXT_DATA )m_cmDevice->GetAccelData();
-    CM_CHK_NULL_RETURN_CMERROR(cmData);
-    PCM_HAL_STATE state = cmData->cmHalState;
-    CM_CHK_NULL_RETURN_CMERROR(state);
+    PCM_HAL_STATE state = nullptr;
+    CM_CHK_NULL_GOTOFINISH_CMERROR(cmData);
+    state = cmData->cmHalState;
+    CM_CHK_NULL_GOTOFINISH_CMERROR(state);
 
     if (!m_isSurfaceUpdateDone)
     {
@@ -1819,7 +1829,7 @@ int32_t CmTaskInternal::UpdateSurfaceStateOnTaskCreation()
             if (m_surfaceArray[i])
             {
                 CmSurface *surface = NULL;
-                CM_CHK_CMSTATUS_RETURN(surfaceMgr->GetSurface(i, surface));
+                CM_CHK_CMSTATUS_GOTOFINISH(surfaceMgr->GetSurface(i, surface));
                 if (surface == nullptr) // surface destroyed but not updated in kernel
                 {
                     continue;
@@ -1897,13 +1907,8 @@ int32_t CmTaskInternal::UpdateSurfaceStateOnTaskCreation()
                         }
                         else
                         {
-                            surfaceLock->Release();
-                            if (curTaskSurfResArray)
-                            {
-                                MOS_FreeMemory(curTaskSurfResArray);
-                                curTaskSurfResArray = nullptr;
-                            }
-                            return CM_INVALID_ARG_INDEX;
+                            hr = CM_INVALID_ARG_INDEX;
+                            goto finish;
                         }
                         break;
 
@@ -1916,21 +1921,21 @@ int32_t CmTaskInternal::UpdateSurfaceStateOnTaskCreation()
         m_isSurfaceUpdateDone = true;
     }
 
-    surfaceLock->Release();
-
     // Check if there is any secure surface.
     if (curTaskSurfCnt > 0 && state->osInterface && state->osInterface->osCpInterface)
     {
         state->osInterface->osCpInterface->PrepareResources(curTaskSurfResArray, curTaskSurfCnt, nullptr, 0);
     }
 
+finish:
+    surfaceLock->Release();
     if (curTaskSurfResArray)
     {
         MOS_FreeMemory(curTaskSurfResArray);
         curTaskSurfResArray = nullptr;
     }
 
-    return CM_SUCCESS;
+    return hr;
 }
 
 #if CM_LOG_ON
@@ -2011,9 +2016,10 @@ int32_t CmTaskInternal::SetProperty(CM_TASK_CONFIG * taskConfig)
     return CM_SUCCESS;
 }
 
-PCM_TASK_CONFIG CmTaskInternal::GetTaskConfig()
+int32_t CmTaskInternal::GetProperty(CM_TASK_CONFIG &taskConfig)
 {
-    return &m_taskConfig;
+    taskConfig = m_taskConfig;
+    return CM_SUCCESS;
 }
 
 void  *CMRT_UMD::CmTaskInternal::GetMediaStatePtr()
