@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -48,6 +48,11 @@ CodechalDebugInterface::~CodechalDebugInterface()
     {
         MOS_Delete(m_configMgr);
     }
+
+    if (!Mos_ResourceIsNull(&m_temp2DSurfForCopy.OsResource))
+    {
+        m_osInterface->pfnFreeResource(m_osInterface, &m_temp2DSurfForCopy.OsResource);
+    }
 }
 
 MOS_STATUS CodechalDebugInterface::Initialize(
@@ -65,6 +70,8 @@ MOS_STATUS CodechalDebugInterface::Initialize(
 
     m_hwInterface = hwInterface;
     m_osInterface = m_hwInterface->GetOsInterface();
+    m_cpInterface = m_hwInterface->GetCpInterface();
+    m_miInterface = m_hwInterface->GetMiInterface();
 
 #ifdef LINUX
     char* customizedOutputPath = getenv("MOS_DEBUG_OUTPUT_LOCATION");
@@ -74,7 +81,7 @@ MOS_STATUS CodechalDebugInterface::Initialize(
         m_outputFilePath.erase(m_outputFilePath.find_last_not_of(" \n\r\t") + 1);
         if (m_outputFilePath[m_outputFilePath.length() - 1] != MOS_DIRECTORY_DELIMITER)
              m_outputFilePath += MOS_DIRECTORY_DELIMITER;
-    } 
+    }
     else
 #endif
     {
@@ -399,11 +406,13 @@ MOS_STATUS CodechalDebugInterface::DumpMDFCurbe(
     }
 
     std::string funcName = m_configMgr->GetMediaStateStr(mediaState);
+    bool binaryDump = m_configMgr->AttrIsEnabled(CodechalDbgAttr::attrDumpBufferInBinary);
+    const char* extType = binaryDump ? CodechalDbgExtType::dat : CodechalDbgExtType::txt;
 
     const char *fileName = CreateFileName(
         funcName.c_str(),
         CodechalDbgBufferType::bufCurbe,
-        CodechalDbgExtType::txt);
+        extType);
 
     curbeAlignedSize = MOS_ALIGN_CEIL(curbeSize, 64);
     curbeAlignedData = (uint8_t *)malloc(curbeAlignedSize * sizeof(uint8_t));
@@ -416,7 +425,14 @@ MOS_STATUS CodechalDebugInterface::DumpMDFCurbe(
     MOS_ZeroMemory(curbeAlignedData, curbeAlignedSize);
     MOS_SecureMemcpy(curbeAlignedData, curbeSize, curbeBuffer, curbeSize);
 
-    eStatus = DumpBufferInHexDwords(curbeAlignedData, curbeAlignedSize);
+    if (binaryDump)
+    {
+        eStatus = DumpBufferInBinary(curbeAlignedData, curbeAlignedSize);
+    }
+    else
+    {
+        eStatus = DumpBufferInHexDwords(curbeAlignedData, curbeAlignedSize);
+    }
 
     free(curbeAlignedData);
 
@@ -487,8 +503,8 @@ MOS_STATUS CodechalDebugInterface::DumpKernelRegion(
 
 MOS_STATUS CodechalDebugInterface::DumpYUVSurface(
     PMOS_SURFACE              surface,
-    const char *              attrName,
-    const char *              surfName,
+    const char*               attrName,
+    const char*               surfName,
     CODECHAL_MEDIA_STATE_TYPE mediaState,
     uint32_t                  width_in,
     uint32_t                  height_in)
@@ -503,20 +519,109 @@ MOS_STATUS CodechalDebugInterface::DumpYUVSurface(
     lockFlags.ReadOnly = 1;
     lockFlags.TiledAsTiled = 1; // Bypass GMM CPU blit due to some issues in GMM CpuBlt function
 
-    uint8_t *lockedAddr = (uint8_t *)m_osInterface->pfnLockResource(m_osInterface, &surface->OsResource, &lockFlags);
+    uint8_t* lockedAddr = (uint8_t*)m_osInterface->pfnLockResource(m_osInterface, &surface->OsResource, &lockFlags);
+    if (lockedAddr == nullptr) // Failed to lock. Try to submit copy task and dump another surface
+    {
+        uint32_t        sizeToBeCopied = 0;
+        MOS_GFXRES_TYPE ResType;
+
+#if LINUX
+        // Linux does not have OsResource->ResType
+        ResType = surface->Type;
+#else
+        ResType = surface->OsResource.ResType;
+#endif
+
+        GMM_RESOURCE_FLAG gmmFlags = surface->OsResource.pGmmResInfo->GetResFlags();
+        bool allocated = false;
+
+        CODECHAL_DEBUG_CHK_STATUS(ReAllocateSurface(
+            &m_temp2DSurfForCopy,
+            surface,
+            "Temp2DSurfForSurfDumper",
+            ResType));
+
+        // Ensure allocated buffer size contains the source surface size
+        if (m_temp2DSurfForCopy.OsResource.pGmmResInfo->GetSizeMainSurface() >= surface->OsResource.pGmmResInfo->GetSizeMainSurface())
+        {
+            sizeToBeCopied = (uint32_t)surface->OsResource.pGmmResInfo->GetSizeMainSurface();
+        }
+
+        if (sizeToBeCopied == 0)
+        {
+            // Currently, MOS's pfnAllocateResource does not support allocate a surface reference to another surface.
+            // When the source surface is not created from Media, it is possible that we cannot allocate the same size as source.
+            // For example, on Gen9, Render target might have GMM set CCS=1 MMC=0, but MOS cannot allocate surface with such combination.
+            // When Gmm allocation parameter is different, the resulting surface size/padding/pitch will be differnt.
+            // Once if MOS can support allocate a surface by reference another surface, we can do a bit to bit copy without problem.
+            CODECHAL_DEBUG_ASSERTMESSAGE("Cannot allocate correct size, failed to copy nonlockable resource");
+            return MOS_STATUS_NULL_POINTER;
+        }
+
+        CODECHAL_DEBUG_VERBOSEMESSAGE("Temp2DSurfaceForCopy width %d, height %d, pitch %d, TileType %d, bIsCompressed %d, CompressionMode %d",
+            m_temp2DSurfForCopy.dwWidth,
+            m_temp2DSurfForCopy.dwHeight,
+            m_temp2DSurfForCopy.dwPitch,
+            m_temp2DSurfForCopy.TileType,
+            m_temp2DSurfForCopy.bIsCompressed,
+            m_temp2DSurfForCopy.CompressionMode);
+
+        if (CopySurfaceData_Vdbox(sizeToBeCopied, &surface->OsResource, &m_temp2DSurfForCopy.OsResource) != MOS_STATUS_SUCCESS)
+        {
+            CODECHAL_DEBUG_ASSERTMESSAGE("CopyDataSurface_Vdbox failed");
+            m_osInterface->pfnFreeResource(m_osInterface, &m_temp2DSurfForCopy.OsResource);
+            return MOS_STATUS_NULL_POINTER;
+        }
+        lockedAddr = (uint8_t*)m_osInterface->pfnLockResource(m_osInterface, &m_temp2DSurfForCopy.OsResource, &lockFlags);
+        CODECHAL_DEBUG_CHK_NULL(lockedAddr);
+
+        if (DumpIsEnabled(CodechalDbgAttr::attrDisableSwizzleForDumps))
+        {
+            if (CodecHal_PictureIsField(m_currPic))
+            {
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
+            else
+            {
+                return DumpNotSwizzled(surfName, m_temp2DSurfForCopy, lockedAddr, sizeToBeCopied);
+            }
+        }
+    }
+
+    uint32_t sizeMain = (uint32_t)(surface->OsResource.pGmmResInfo->GetSizeMainSurface());
+    if (DumpIsEnabled(CodechalDbgAttr::attrDisableSwizzleForDumps))
+    {
+        if (CodecHal_PictureIsField(m_currPic))
+        {
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+        else
+        {
+            return DumpNotSwizzled(surfName, *surface, lockedAddr, sizeMain);
+        }
+    }
+
+    uint8_t* surfBaseAddr = (uint8_t*)MOS_AllocMemory(sizeMain);
+    CODECHAL_DEBUG_CHK_NULL(surfBaseAddr);
+
+    if (DumpIsEnabled(CodechalDbgAttr::attrForceYUVDumpWithMemcpy))
+    {
+        MOS_SecureMemcpy(surfBaseAddr, sizeMain, lockedAddr, sizeMain); // Firstly, copy to surfBaseAddr to faster unlock resource
+        m_osInterface->pfnUnlockResource(m_osInterface, &surface->OsResource);
+        lockedAddr = surfBaseAddr;
+        surfBaseAddr = (uint8_t*)MOS_AllocMemory(sizeMain);
+        CODECHAL_DEBUG_CHK_NULL(surfBaseAddr);
+    }
 
     // Always use MOS swizzle instead of GMM Cpu blit
-    uint32_t sizeMain = (uint32_t)(surface->OsResource.pGmmResInfo->GetSizeMainSurface());
-    uint8_t *surfBaseAddr = (uint8_t*)MOS_AllocMemory(sizeMain);
-
     CODECHAL_DEBUG_CHK_NULL(surfBaseAddr);
     Mos_SwizzleData(lockedAddr, surfBaseAddr, surface->TileType, MOS_TILE_LINEAR, sizeMain / surface->dwPitch, surface->dwPitch, 0);
 
-    uint8_t *data = surfBaseAddr;
+    uint8_t* data = surfBaseAddr;
     data += surface->dwOffset + surface->YPlaneOffset.iYOffset * surface->dwPitch;
 
-    uint32_t width  = width_in ? width_in : surface->dwWidth;
-    uint32_t height = height_in? height_in : surface->dwHeight;
+    uint32_t width = width_in ? width_in : surface->dwWidth;
+    uint32_t height = height_in ? height_in : surface->dwHeight;
 
     switch (surface->Format)
     {
@@ -531,6 +636,7 @@ MOS_STATUS CodechalDebugInterface::DumpYUVSurface(
     case Format_Y410:  //444 10bit -- A[31:30]:V[29:20]:Y[19:10]:U[9:0] = 32bits per pixel = 4Bytes per pixel
     case Format_R10G10B10A2:
     case Format_AYUV:  //444 8bit  -- A[31:24]:Y[23:16]:U[15:8]:V[7:0] = 32bits per pixel = 4Bytes per pixel
+    case Format_A8R8G8B8:
         width = width << 2;
         break;
     default:
@@ -552,10 +658,9 @@ MOS_STATUS CodechalDebugInterface::DumpYUVSurface(
         height /= 2;
     }
 
-    const char *funcName = (m_codecFunction == CODECHAL_FUNCTION_DECODE) ? "_DEC" :(m_codecFunction == CODECHAL_FUNCTION_CENC_DECODE ? "_DEC" : "_ENC");
-    std::string bufName  = std::string(surfName) + "_w[" + std::to_string(surface->dwWidth) + "]_h[" + std::to_string(surface->dwHeight) + "]_p[" + std::to_string(pitch) + "]";
-
-    const char *filePath = CreateFileName(funcName, bufName.c_str(), CodechalDbgExtType::yuv);
+    const char* funcName = (m_codecFunction == CODECHAL_FUNCTION_DECODE) ? "_DEC" : (m_codecFunction == CODECHAL_FUNCTION_CENC_DECODE ? "_DEC" : "_ENC");
+    std::string bufName = std::string(surfName) + "_w[" + std::to_string(surface->dwWidth) + "]_h[" + std::to_string(surface->dwHeight) + "]_p[" + std::to_string(pitch) + "]";
+    const char* filePath = CreateFileName(funcName, bufName.c_str(), CodechalDbgExtType::yuv);
 
     std::ofstream ofs(filePath, std::ios_base::out | std::ios_base::binary);
     if (ofs.fail())
@@ -565,88 +670,93 @@ MOS_STATUS CodechalDebugInterface::DumpYUVSurface(
 
     // write luma data to file
     for (uint32_t h = 0; h < height; h++)
-    {
-        ofs.write((char* )data, width);
-        data += pitch;
-    }
-
-    switch (surface->Format)
-    {
-    case Format_NV12:
-    case Format_P010:
-    case Format_P016:
-        height >>= 1;
-        break;
-    case  Format_Y416:
-    case  Format_AUYV:
-    case  Format_Y410: //444 10bit
-    case  Format_R10G10B10A2:
-        height *= 2;
-        break;
-    case  Format_YUY2:
-    case  Format_YUYV:
-    case  Format_YUY2V:
-    case  Format_Y216V:
-    case  Format_YVYU:
-    case  Format_UYVY:
-    case  Format_VYUY:
-    case  Format_Y216: //422 16bit
-    case  Format_Y210: //422 10bit
-    case  Format_P208: //422 8bit
-        break;
-    case Format_422V:
-    case Format_IMC3:
-        height = height / 2;
-        break;
-    case  Format_AYUV:
-    default:
-        height = 0;
-        break;
-    }
-
-uint8_t *vPlaneData = surfBaseAddr;
-#ifdef LINUX
-    data = surfBaseAddr + surface->UPlaneOffset.iSurfaceOffset;
-    if (surface->Format == Format_422V
-        || surface->Format == Format_IMC3)
-    {
-        vPlaneData = surfBaseAddr + surface->VPlaneOffset.iSurfaceOffset;
-    }
-#else
-    data = surfBaseAddr + surface->UPlaneOffset.iLockSurfaceOffset;
-    if (surface->Format == Format_422V
-        || surface->Format == Format_IMC3)
-    {
-        vPlaneData = surfBaseAddr + surface->VPlaneOffset.iLockSurfaceOffset;
-    }
-
-#endif
-
-    // write chroma data to file
-    for (uint32_t h = 0; h < height; h++)
     {
         ofs.write((char*)data, width);
         data += pitch;
     }
 
-    // write v planar data to file
-    if (surface->Format == Format_422V
-        || surface->Format == Format_IMC3)
+    if (surface->Format != Format_A8B8G8R8)
     {
+        switch (surface->Format)
+        {
+        case Format_NV12:
+        case Format_P010:
+        case Format_P016:
+            height >>= 1;
+            break;
+        case  Format_Y416:
+        case  Format_AUYV:
+        case  Format_R10G10B10A2:
+            height *= 2;
+            break;
+        case  Format_YUY2:
+        case  Format_YUYV:
+        case  Format_YUY2V:
+        case  Format_Y216V:
+        case  Format_YVYU:
+        case  Format_UYVY:
+        case  Format_VYUY:
+        case  Format_Y216: //422 16bit
+        case  Format_Y210: //422 10bit
+        case  Format_P208: //422 8bit
+            break;
+        case Format_422V:
+        case Format_IMC3:
+            height = height / 2;
+            break;
+        case  Format_AYUV:
+        default:
+            height = 0;
+            break;
+        }
+
+        uint8_t* vPlaneData = surfBaseAddr;
+#ifdef LINUX
+        data = surfBaseAddr + surface->UPlaneOffset.iSurfaceOffset;
+        if (surface->Format == Format_422V
+            || surface->Format == Format_IMC3)
+        {
+            vPlaneData = surfBaseAddr + surface->VPlaneOffset.iSurfaceOffset;
+    }
+#else
+        data = surfBaseAddr + surface->UPlaneOffset.iLockSurfaceOffset;
+        if (surface->Format == Format_422V
+            || surface->Format == Format_IMC3)
+        {
+            vPlaneData = surfBaseAddr + surface->VPlaneOffset.iLockSurfaceOffset;
+        }
+
+#endif
+
+        // write chroma data to file
         for (uint32_t h = 0; h < height; h++)
         {
-            ofs.write((char *)vPlaneData, width);
-            vPlaneData += pitch;
+            ofs.write((char*)data, width);
+            data += pitch;
+        }
+
+        // write v planar data to file
+        if (surface->Format == Format_422V
+            || surface->Format == Format_IMC3)
+        {
+            for (uint32_t h = 0; h < height; h++)
+            {
+                ofs.write((char*)vPlaneData, width);
+                vPlaneData += pitch;
+            }
         }
     }
-
     ofs.close();
 
-    if (surfBaseAddr)
+    if (DumpIsEnabled(CodechalDbgAttr::attrForceYUVDumpWithMemcpy))
+    {
+        MOS_FreeMemory(lockedAddr);
+    }
+    else
     {
         m_osInterface->pfnUnlockResource(m_osInterface, &surface->OsResource);
-        MOS_FreeMemory(surfBaseAddr);
     }
+    MOS_FreeMemory(surfBaseAddr);
 
     return MOS_STATUS_SUCCESS;
 }
@@ -978,6 +1088,236 @@ MOS_STATUS CodechalDebugInterface::DeleteCfgLinkNode(uint32_t frameIdx)
    return m_configMgr->DeleteCfgNode(frameIdx);
 }
 
+
+MOS_STATUS CodechalDebugInterface::ReAllocateSurface(
+    PMOS_SURFACE    pSurface,
+    PMOS_SURFACE    pSrcSurf,
+    PCCHAR          pSurfaceName,
+    MOS_GFXRES_TYPE DefaultResType)
+{
+    MOS_ALLOC_GFXRES_PARAMS AllocParams;
+
+    CODECHAL_DEBUG_ASSERT(m_osInterface);
+    CODECHAL_DEBUG_ASSERT(&pSurface->OsResource);
+
+    // bCompressible should be compared with bCompressible since it is inited by bCompressible in previous call
+    // TileType of surface should be compared since we need to reallocate surface if TileType changes
+    if (!Mos_ResourceIsNull(&pSurface->OsResource)               &&
+        (pSurface->dwWidth         == pSrcSurf->dwWidth)         &&
+        (pSurface->dwHeight        == pSrcSurf->dwHeight)        &&
+        (pSurface->Format          == pSrcSurf->Format)          &&
+        (pSurface->bCompressible   == pSrcSurf->bCompressible)   &&
+        (pSurface->CompressionMode == pSrcSurf->CompressionMode) &&
+        (pSurface->TileType        == pSrcSurf->TileType))
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+    MOS_ZeroMemory(&AllocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
+
+#if !EMUL
+    //  Need to reallocate surface according to expected tiletype instead of tiletype of the surface what we have 
+    if ((pSurface->OsResource.pGmmResInfo != nullptr) &&
+        (pSurface->TileType               == pSrcSurf->TileType))
+    {
+        // Reallocate but use same tile type and resource type as current
+        AllocParams.TileType = pSurface->OsResource.TileType;
+        AllocParams.Type     = DefaultResType;
+    }
+    else
+#endif
+    {
+        // First time allocation. Caller must specify default params
+        AllocParams.TileType = pSrcSurf->TileType;
+        AllocParams.Type     = DefaultResType;
+    }
+
+    AllocParams.dwWidth         = pSrcSurf->dwWidth;
+    AllocParams.dwHeight        = pSrcSurf->dwHeight;
+    AllocParams.Format          = pSrcSurf->Format;
+    AllocParams.bIsCompressible = pSrcSurf->bCompressible;
+    AllocParams.CompressionMode = pSrcSurf->CompressionMode;
+    AllocParams.pBufName        = pSurfaceName;
+    AllocParams.dwArraySize     = 1;
+
+    // Delete resource if already allocated
+    m_osInterface->pfnFreeResource(m_osInterface, &(pSurface->OsResource));
+
+    // Allocate surface
+    CODECHAL_PUBLIC_CHK_STATUS_RETURN(m_osInterface->pfnAllocateResource(
+        m_osInterface,
+        &AllocParams,
+        &pSurface->OsResource));
+
+    pSurface->Format        = pSrcSurf->Format;
+    pSurface->dwWidth       = pSrcSurf->dwWidth;
+    pSurface->dwHeight      = pSrcSurf->dwHeight;
+    pSurface->dwPitch       = pSrcSurf->dwPitch;
+    pSurface->dwDepth       = pSrcSurf->dwDepth;
+    pSurface->dwQPitch      = pSrcSurf->dwQPitch;
+    pSurface->bArraySpacing = pSrcSurf->bArraySpacing;
+    pSurface->TileType      = pSrcSurf->TileType;
+    pSurface->dwOffset      = pSrcSurf->RenderOffset.YUV.Y.BaseOffset;
+    pSurface->YPlaneOffset.iSurfaceOffset = pSrcSurf->RenderOffset.YUV.Y.BaseOffset;
+    pSurface->YPlaneOffset.iXOffset = pSrcSurf->RenderOffset.YUV.Y.XOffset;
+    pSurface->YPlaneOffset.iYOffset =
+        (pSurface->YPlaneOffset.iSurfaceOffset - pSurface->dwOffset) / pSurface->dwPitch +
+        pSrcSurf->RenderOffset.YUV.Y.YOffset;
+    pSurface->UPlaneOffset.iSurfaceOffset = pSrcSurf->RenderOffset.YUV.U.BaseOffset;
+    pSurface->UPlaneOffset.iXOffset       = pSrcSurf->RenderOffset.YUV.U.XOffset;
+    pSurface->UPlaneOffset.iYOffset       =
+        (pSurface->UPlaneOffset.iSurfaceOffset - pSurface->dwOffset) / pSurface->dwPitch +
+        pSrcSurf->RenderOffset.YUV.U.YOffset;
+    pSurface->UPlaneOffset.iLockSurfaceOffset = pSrcSurf->LockOffset.YUV.U;
+    pSurface->VPlaneOffset.iSurfaceOffset = pSrcSurf->RenderOffset.YUV.V.BaseOffset;
+    pSurface->VPlaneOffset.iXOffset       = pSrcSurf->RenderOffset.YUV.V.XOffset;
+    pSurface->VPlaneOffset.iYOffset       =
+        (pSurface->VPlaneOffset.iSurfaceOffset - pSurface->dwOffset) / pSurface->dwPitch +
+        pSrcSurf->RenderOffset.YUV.V.YOffset;
+    pSurface->VPlaneOffset.iLockSurfaceOffset = pSrcSurf->LockOffset.YUV.V;
+    pSurface->bCompressible     = pSrcSurf->bCompressible;
+    pSurface->CompressionMode   = pSrcSurf->CompressionMode;
+    pSurface->bIsCompressed     = pSrcSurf->bIsCompressed;
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS CodechalDebugInterface::CopySurfaceData_Vdbox(
+    uint32_t      dwDataSize,
+    PMOS_RESOURCE presSourceSurface,
+    PMOS_RESOURCE presCopiedSurface)
+{
+    MOS_COMMAND_BUFFER                      CmdBuffer;
+    MHW_MI_FLUSH_DW_PARAMS                  FlushDwParams;
+    MHW_GENERIC_PROLOG_PARAMS               genericPrologParams;
+    MHW_CP_COPY_PARAMS                      cpCopyParams;
+    MOS_NULL_RENDERING_FLAGS                NullRenderingFlags;
+    MOS_GPU_CONTEXT                         orgGpuContext;
+
+    if (!m_vdboxContextCreated)
+    {
+        MOS_GPUCTX_CREATOPTIONS createOption;
+
+        CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnCreateGpuContext(
+            m_osInterface,
+            MOS_GPU_CONTEXT_VIDEO,
+            MOS_GPU_NODE_VIDEO,
+            &createOption));
+
+        // Register VDbox GPU context with the Batch Buffer completion event
+        CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnRegisterBBCompleteNotifyEvent(
+            m_osInterface,
+            MOS_GPU_CONTEXT_VIDEO));
+
+        m_vdboxContextCreated = true;
+    }
+
+    CODECHAL_DEBUG_CHK_NULL(m_cpInterface);
+    CODECHAL_DEBUG_CHK_NULL(m_osInterface);
+    CODECHAL_DEBUG_CHK_NULL(m_miInterface);
+    CODECHAL_DEBUG_CHK_NULL(m_osInterface->pfnGetWaTable(m_osInterface));
+
+    orgGpuContext   = m_osInterface->CurrentGpuContextOrdinal;
+
+    // Due to VDBOX cryto copy limitation, the size must be Cache line aligned
+    if (!MOS_IS_ALIGNED(dwDataSize, MHW_CACHELINE_SIZE))
+    {
+        CODECHAL_DEBUG_ASSERTMESSAGE("Size is not CACHE line aligned, cannot use VDBOX to copy.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
+    CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnSetGpuContext(m_osInterface, MOS_GPU_CONTEXT_VIDEO));
+    m_osInterface->pfnResetOsStates(m_osInterface);
+
+    // Register the target resource
+    CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnRegisterResource(
+        m_osInterface,
+        presCopiedSurface,
+        true,
+        true));
+
+    // Register the source resource
+    CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnRegisterResource(
+        m_osInterface,
+        presSourceSurface,
+        false,
+        true));
+
+    CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnGetCommandBuffer(m_osInterface, &CmdBuffer, 0));
+
+    MOS_ZeroMemory(&genericPrologParams, sizeof(genericPrologParams));
+    genericPrologParams.pOsInterface    = m_osInterface;
+    genericPrologParams.pvMiInterface   = m_miInterface;
+    genericPrologParams.bMmcEnabled     = false;
+    CODECHAL_DEBUG_CHK_STATUS(Mhw_SendGenericPrologCmd(&CmdBuffer, &genericPrologParams));
+
+    MOS_ZeroMemory(&cpCopyParams, sizeof(cpCopyParams));
+    cpCopyParams.size = dwDataSize;
+    cpCopyParams.presSrc = presSourceSurface;
+    cpCopyParams.presDst = presCopiedSurface;
+    cpCopyParams.isEncodeInUse = false;
+
+    CODECHAL_DEBUG_CHK_STATUS(m_cpInterface->SetCpCopy(m_osInterface, &CmdBuffer, &cpCopyParams));
+
+    // MI_FLUSH
+    MOS_ZeroMemory(&FlushDwParams, sizeof(FlushDwParams));
+    CODECHAL_DEBUG_CHK_STATUS(m_miInterface->AddMiFlushDwCmd(
+        &CmdBuffer,
+        &FlushDwParams));
+
+    CODECHAL_DEBUG_CHK_STATUS(m_miInterface->AddMiBatchBufferEnd(
+        &CmdBuffer,
+        nullptr));
+
+    m_osInterface->pfnReturnCommandBuffer(m_osInterface, &CmdBuffer, 0);
+
+    NullRenderingFlags = m_osInterface->pfnGetNullHWRenderFlags(m_osInterface);
+
+    CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnSubmitCommandBuffer(
+        m_osInterface,
+        &CmdBuffer,
+        NullRenderingFlags.CtxVideo || NullRenderingFlags.CodecGlobal || NullRenderingFlags.CtxVideo || NullRenderingFlags.VPGobal));
+
+    CODECHAL_DEBUG_CHK_STATUS(m_osInterface->pfnSetGpuContext(m_osInterface, orgGpuContext));
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS CodechalDebugInterface::DumpNotSwizzled(
+    std::string  surfName,
+    MOS_SURFACE& surf,
+    uint8_t*     lockedAddr,
+    int32_t      size)
+{
+    const char* funcName = (m_codecFunction == CODECHAL_FUNCTION_DECODE) ? "_DEC" : (m_codecFunction == CODECHAL_FUNCTION_CENC_DECODE ? "_DEC" : "_ENC");
+    int YOffset = surf.dwOffset + surf.YPlaneOffset.iYOffset * surf.dwPitch;
+
+#ifdef LINUX
+    int UOffset = surf.UPlaneOffset.iSurfaceOffset;
+    int VOffset = surf.VPlaneOffset.iSurfaceOffset;
+#else
+    int UOffset = surf.UPlaneOffset.iLockSurfaceOffset;
+    int VOffset = surf.VPlaneOffset.iLockSurfaceOffset;
+#endif
+
+    std::string bufName = std::string(surfName) + "NotSwizzled_format[" + std::to_string((int)surf.Format) + "]_w[" + std::to_string(surf.dwWidth)
+        + "]_h[" + std::to_string(surf.dwHeight) + "]_p[" + std::to_string(surf.dwPitch) + "]_srcTiling[" + std::to_string((int)surf.TileType) 
+        + "]_sizeMain[" + std::to_string(size) + "]_YOffset[" + std::to_string(YOffset) 
+        + "]_UOffset[" + std::to_string(UOffset) + "]_VOffset[" + std::to_string(VOffset) + "]";
+
+    const char* filePath = CreateFileName(funcName, bufName.c_str(), CodechalDbgExtType::yuv);
+    std::ofstream ofs(filePath, std::ios_base::out | std::ios_base::binary);
+    if (ofs.fail())
+    {
+        return MOS_STATUS_UNKNOWN;
+    }
+
+    uint8_t* data = lockedAddr;
+    ofs.write((char*)data, size);
+    ofs.close();
+
+    m_osInterface->pfnUnlockResource(m_osInterface, &surf.OsResource);    
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS CodechalDebugInterface::DumpBufferInBinary(uint8_t *data, uint32_t size)
 {
     CODECHAL_DEBUG_CHK_NULL(data);
