@@ -27,357 +27,7 @@
 #include "codechal_decoder.h"
 #include "codeckrnheader.h"
 
-//!
-//! \class MediaWalkerFieldScalingStaticData
-//! \brief This class defines the member fields, functions etc. for Media Walker Static Data used by Field Downscaling Kernel.
-//!
-class MediaWalkerFieldScalingStaticData
-{
-public:
-    //!
-    //! \brief    Constructor
-    //!
-    MediaWalkerFieldScalingStaticData();
-
-    //!
-    //! \brief    Destructor
-    //!
-    ~MediaWalkerFieldScalingStaticData() {};
-
-    //!
-    //! \struct MediaWalkerData
-    //! \brief Media Walker Data bit definitions
-    //!
-    struct MediaWalkerData
-    {
-        // uint32_t 0 - GRF R1.0
-        union
-        {
-            // CSC
-            struct
-            {
-                uint32_t       m_cscConstantC0                  : 16;
-                uint32_t       m_cscConstantC1                  : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword00;
-
-        // uint32_t 1 - GRF R1.1
-        union
-        {
-            // CSC
-            struct
-            {
-                uint32_t       m_cscConstantC2                  : 16;
-                uint32_t       m_cscConstantC3                  : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword01;
-
-        // uint32_t 2 - GRF R1.2
-        union
-        {
-            // CSC
-            struct
-            {
-                uint32_t       m_cscConstantC4                  : 16;
-                uint32_t       m_cscConstantC5                  : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword02;
-
-        // uint32_t 3 - GRF R1.3
-        union
-        {
-            // CSC
-            struct
-            {
-                uint32_t       m_cscConstantC6                  : 16;
-                uint32_t       m_cscConstantC7                  : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword03;
-
-        // uint32_t 4 - GRF R1.4
-        union
-        {
-            // CSC
-            struct
-            {
-                uint32_t       m_cscConstantC8                  : 16;
-                uint32_t       m_cscConstantC9                  : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword04;
-
-        // uint32_t 5 - GRF R1.5
-        union
-        {
-            // CSC
-            struct
-            {
-                uint32_t       m_cscConstantC10                 : 16;
-                uint32_t       m_cscConstantC11                 : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword05;
-
-        // uint32_t 6 - GRF R1.6
-        uint32_t           m_padConstantBlend;
-
-        // uint32_t 7 - GRF R1.7
-        union
-        {
-            struct
-            {
-                uint32_t       m_reserved                       : 24;
-                uint32_t       m_pointerToInlineParameters      : 8;
-            };
-
-            uint32_t       m_value;
-        } m_dword07;
-
-        // uint32_t 8 - GRF R2.0
-        union
-        {
-            struct
-            {
-                uint32_t       m_destinationRectangleWidth      : 16;
-                uint32_t       m_destinationRectangleHeight     : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword08;
-
-        // uint32_t 9 - GRF R2.1
-        union
-        {
-            struct
-            {
-                uint32_t       m_reserved0                      : 27;
-                uint32_t       m_iefByPassEnable                : 1;
-                uint32_t       m_reserved1                      : 4;
-            };
-
-            uint32_t       m_value;
-        } m_dword09;
-
-        // uint32_t 10 - GRF R2.2
-        union
-        {
-            struct
-            {
-                uint32_t       m_reserved0                      : 24;
-                uint32_t       m_chromaSitingLocation           : 3;
-                uint32_t       m_reserved1                      : 5;
-            };
-
-            uint32_t       m_value;
-        } m_dword10;
-
-        // uint32_t 11 - 13 - GRF R2.3 - 2.5
-        uint32_t           m_pad0[3];
-
-        // uint32_t 14 - GRF R2.6
-        union
-        {
-            // Lumakey, NLAS
-            struct
-            {
-                uint32_t       m_lumakeyLowThreshold            : 8;
-                uint32_t       m_lumakeyHighThreshold           : 8;
-                uint32_t       m_nlasEnable                     : 8;
-                uint32_t       m_reserved                       : 8;
-            };
-
-            uint32_t       m_value;
-        } m_dword14;
-
-        // uint32_t 15 - GRF R2.7
-        union
-        {
-            // Save
-            struct
-            {
-                uint8_t        m_destinationPackedYOffset;
-                uint8_t        m_destinationPackedUOffset;
-                uint8_t        m_destinationPackedVOffset;
-                uint8_t        m_destinationRGBFormat;
-            };
-
-            uint32_t       m_value;
-        } m_dword15;
-
-        // uint32_t 16 - GRF R3.0
-        union
-        {
-            // Sampler Load
-            struct
-            {
-                float          m_horizontalScalingStepRatioLayer0;
-            };
-
-            uint32_t       m_value;
-        } m_dword16;
-
-        // uint32_t 17 - 23 - GRF R3.1 - R3.7
-        uint32_t           m_pad1[7];
-
-        // uint32_t 24 - GRF R4.0
-        union
-        {
-            // Sampler Load
-            struct
-            {
-                float          m_verticalScalingStepRatioLayer0;
-            };
-
-            // Dataport Load
-            struct
-            {
-                uint8_t        m_sourcePackedYOffset;
-                uint8_t        m_sourcePackedUOffset;
-                uint8_t        m_sourcePackedVOffset;
-                uint8_t        m_reserved;
-            };
-
-            uint32_t       m_value;
-        } m_dword24;
-
-        // uint32_t 25 - 31 - GRF R4.1 - R4.7
-        uint32_t           m_pad2[7];
-
-        // uint32_t 32 - GRF R5.0
-        union
-        {
-            // Sampler Load
-            struct
-            {
-                float          m_verticalFrameOriginLayer0;
-            };
-
-            uint32_t       m_value;
-        } m_dword32;
-
-        // uint32_t 33 - 39 - GRF R5.1 - R5.7
-        uint32_t           m_pad3[7];
-
-        // uint32_t 40 - GRF R6.0
-        union
-        {
-            // Sampler Load
-            struct
-            {
-                float          m_horizontalFrameOriginLayer0;
-            };
-
-            uint32_t       m_value;
-        } m_dword40;
-
-        // uint32_t 41 - 47 - GRF R6.1 - R6.7
-        uint32_t           m_pad4[7];
-
-        // uint32_t 48  - GRF R7.0
-        union
-        {
-            struct
-            {
-                uint32_t       m_destXTopLeftLayer0             : 16;
-                uint32_t       m_destYTopLeftLayer0             : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword48;
-
-        // uint32_t 49 - 55 - GRF R7.1 - R7.7
-        uint32_t           m_pad5[7];
-
-        // uint32_t 56  - GRF R8.0
-        union
-        {
-            struct
-            {
-                uint32_t       m_destXBottomRightLayer0         : 16;
-                uint32_t       m_destYBottomRightLayer0         : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword56;
-
-        // uint32_t 57 - 63 - GRF R8.1
-        uint32_t           m_pad6[7];
-
-        // uint32_t 64  - GRF R9.0
-        union
-        {
-            struct
-            {
-                float          m_mainVideoXScalingStepLeft;
-            };
-
-            uint32_t       m_value;
-        } m_dword64;
-
-        // DWORD65  - GRF R9.1
-        union
-        {
-            struct
-            {
-                float          m_videoStepDeltaForNonLinearRegion;
-            };
-
-            uint32_t       m_value;
-        } m_dword65;
-
-        // DWORD66  - GRF R9.2
-        union
-        {
-            struct
-            {
-                uint32_t       m_startofLinearScalingInPixelPositionC0          : 16;
-                uint32_t       m_startofRHSNonLinearScalingInPixelPositionC1    : 16;
-            };
-
-            uint32_t       m_value;
-        } m_dword66;
-
-        // uint32_t 67 - GRF R9.3
-        union
-        {
-            // Sampler Load
-            struct
-            {
-                float          m_mainVideoXScalingStepCenter;
-            };
-
-            uint32_t       m_value;
-        } m_dword67;
-
-        // uint32_t 68 - GRF R9.4
-        union
-        {
-            // Sampler Load
-            struct
-            {
-                float          m_mainVideoXScalingStepRight;
-            };
-
-            uint32_t       m_value;
-        } m_dword68;
-
-        // uint32_t 69-71 - Padding is needed as we program ConstantURBEntryReadLength  = iCurbeLength >> 5
-        uint32_t           m_pad[3];
-    } m_mediaWalkerData;                                              //!< media walker data
-
-    static const size_t m_byteSize = sizeof(MediaWalkerData);         //!< byte size of media walker data
-};
-
+// Construct function of Class MediaWalkerFieldScalingStaticData
 MediaWalkerFieldScalingStaticData::MediaWalkerFieldScalingStaticData()
 {
     CODECHAL_DECODE_FUNCTION_ENTER;
@@ -407,6 +57,8 @@ FieldScalingInterface::FieldScalingInterface(CodechalHwInterface *hwInterface)
 
     m_kernelUID[stateNv12] = IDR_CODEC_ALLPL2ToNV12iScale;
     m_kernelUID[stateYuy2] = IDR_CODEC_ALLPL2ToPAiScale;
+
+    m_curbeLength = MediaWalkerFieldScalingStaticData::m_byteSize;
 }
 
 FieldScalingInterface::~FieldScalingInterface()
@@ -444,7 +96,7 @@ MOS_STATUS FieldScalingInterface::InitInterfaceStateHeapSetting(
             &m_kernelBinary[krnlIdx],
             &m_kernelSize[krnlIdx]));
 
-        kernelState->KernelParams.iCurbeLength  = MediaWalkerFieldScalingStaticData::m_byteSize;
+        kernelState->KernelParams.iCurbeLength  = m_curbeLength;
         kernelState->KernelParams.pBinary       = m_kernelBinary[krnlIdx];
         kernelState->KernelParams.iSize         = m_kernelSize[krnlIdx];
 
@@ -778,7 +430,7 @@ MOS_STATUS FieldScalingInterface::DoFieldScaling(
     // Source Surface
     // Top Field
     CODECHAL_SURFACE_CODEC_PARAMS surfaceCodecParams;
-    memset(&surfaceCodecParams, 0, sizeof(CODECHAL_SURFACE_CODEC_PARAMS));
+    MOS_ZeroMemory(&surfaceCodecParams, sizeof(CODECHAL_SURFACE_CODEC_PARAMS));
     surfaceCodecParams.bIs2DSurface               = true;
     surfaceCodecParams.bUseHalfHeight             = true;
     surfaceCodecParams.bUseUVPlane                = true;
@@ -821,7 +473,7 @@ MOS_STATUS FieldScalingInterface::DoFieldScaling(
         kernelState));
 
     // Destination Surface (NV12 & YUY2, RGB8 support is not yet implemented)
-    memset(&surfaceCodecParams, 0, sizeof(CODECHAL_SURFACE_CODEC_PARAMS));
+    MOS_ZeroMemory(&surfaceCodecParams, sizeof(CODECHAL_SURFACE_CODEC_PARAMS));
     surfaceCodecParams.bIs2DSurface               = true;
     surfaceCodecParams.psSurface                  = procParams->pOutputSurface;
     surfaceCodecParams.bMediaBlockRW              = true;
