@@ -29,6 +29,7 @@
 #include "codechal_decode_vp8.h"
 #include "codec_def_vp8_probs.h"
 #include "codechal_mmc_decode_vp8.h"
+#include "hal_oca_interface.h"
 #if USE_CODECHAL_DEBUG_TOOL
 #include <sstream>
 #include <fstream>
@@ -1127,6 +1128,10 @@ MOS_STATUS CodechalDecodeVp8::SetFrameStates()
     m_dataSize          = m_decodeParams.m_dataSize;
     m_dataOffset        = m_decodeParams.m_dataOffset;
     m_destSurface       = *(m_decodeParams.m_destSurface);
+    m_presLastRefSurface    = m_decodeParams.m_presNoneRegLastRefFrame;
+    m_presAltRefSurface     = m_decodeParams.m_presNoneRegAltRefFrame;
+    m_presGoldenRefSurface  = m_decodeParams.m_presNoneRegGoldenRefFrame;
+
     m_resDataBuffer     = *(m_decodeParams.m_dataBuffer);
     m_vp8PicParams      = (PCODEC_VP8_PIC_PARAMS)m_decodeParams.m_picParams;
     m_vp8IqMatrixParams = (PCODEC_VP8_IQ_MATRIX_PARAMS)m_decodeParams.m_iqMatrixBuffer;
@@ -1234,14 +1239,38 @@ MOS_STATUS CodechalDecodeVp8::DecodeStateLevel()
     }
     else
     {
-        m_presLastRefSurface   = &(m_vp8RefList[m_vp8PicParams->ucLastRefPicIndex]->resRefPic);
-        m_presGoldenRefSurface = &(m_vp8RefList[m_vp8PicParams->ucGoldenRefPicIndex]->resRefPic);
-        m_presAltRefSurface    = &(m_vp8RefList[m_vp8PicParams->ucAltRefPicIndex]->resRefPic);
+        if((Mos_ResourceIsNull(&m_vp8RefList[m_vp8PicParams->ucLastRefPicIndex]->resRefPic)) && (m_presLastRefSurface))
+        {
+           m_vp8RefList[m_vp8PicParams->ucLastRefPicIndex]->resRefPic = *m_presLastRefSurface;
+        }
+        else
+        {
+           m_presLastRefSurface = &(m_vp8RefList[m_vp8PicParams->ucLastRefPicIndex]->resRefPic);
+        }
+        if((Mos_ResourceIsNull(&m_vp8RefList[m_vp8PicParams->ucGoldenRefPicIndex]->resRefPic)) && (m_presGoldenRefSurface))
+        {
+           m_vp8RefList[m_vp8PicParams->ucGoldenRefPicIndex]->resRefPic = *m_presGoldenRefSurface;
+        }
+        else
+        {
+           m_presGoldenRefSurface = &(m_vp8RefList[m_vp8PicParams->ucGoldenRefPicIndex]->resRefPic);
+        }
+        if((Mos_ResourceIsNull(&m_vp8RefList[m_vp8PicParams->ucAltRefPicIndex]->resRefPic)) && (m_presAltRefSurface))
+        {
+           m_vp8RefList[m_vp8PicParams->ucAltRefPicIndex]->resRefPic = *m_presAltRefSurface;
+        }
+        else
+        {
+           m_presAltRefSurface = &(m_vp8RefList[m_vp8PicParams->ucAltRefPicIndex]->resRefPic);
+        }
     }
 
     MOS_COMMAND_BUFFER cmdBuffer;
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &cmdBuffer, 0));
 
+    auto mmioRegisters = m_hwInterface->GetMfxInterface()->GetMmioRegisters(m_vdboxIndex);
+    HalOcaInterface::On1stLevelBBStart(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->CurrentGpuContextHandle, *m_miInterface, *mmioRegisters);
+
     MHW_VDBOX_PIPE_MODE_SELECT_PARAMS pipeModeSelectParams;
     pipeModeSelectParams.Mode               = m_mode;
     pipeModeSelectParams.bStreamOutEnabled  = m_streamOutEnabled;
@@ -1266,7 +1295,9 @@ MOS_STATUS CodechalDecodeVp8::DecodeStateLevel()
         pipeBufAddrParams.psPreDeblockSurface = &m_destSurface;
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetPipeBufAddr(&pipeBufAddrParams));
+#endif
 
     // when there is no last, golden and alternate reference,
     // the index is set to the destination frame index
@@ -1293,9 +1324,11 @@ MOS_STATUS CodechalDecodeVp8::DecodeStateLevel()
         }
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->CheckReferenceList(&pipeBufAddrParams));
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetRefrenceSync(m_disableDecodeSyncLock, m_disableLockForTranscode));
+#endif
 
     MHW_VDBOX_IND_OBJ_BASE_ADDR_PARAMS indObjBaseAddrParams;
     MOS_ZeroMemory(&indObjBaseAddrParams, sizeof(indObjBaseAddrParams));
@@ -1426,6 +1459,8 @@ MOS_STATUS CodechalDecodeVp8::DecodePrimitiveLevel()
         m_huCCopyInUse = false;
     }
 
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_videoContextUsesNullHw));
 
     CODECHAL_DEBUG_TOOL(
@@ -1498,6 +1533,7 @@ CodechalDecodeVp8::CodechalDecodeVp8(
                                             m_picHeightInMbLastMaxAlloced(0),
                                             m_shortFormatInUse(false),
                                             m_dataSize(0),
+                                            m_dataOffset(0),
                                             m_vp8PicParams(nullptr),
                                             m_vp8IqMatrixParams(nullptr),
                                             m_presLastRefSurface(nullptr),
