@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2014-2017, Intel Corporation
+* Copyright (c) 2014-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -27,6 +27,7 @@
 
 #include "codechal_encode_sfc.h"
 #include "codechal_encoder_base.h"
+#include "hal_oca_interface.h"
 
 #define CODECHAL_IS_BT601_CSPACE(format)                \
         ( (format == MHW_CSpace_BT601)               || \
@@ -640,6 +641,8 @@ MOS_STATUS CodecHalEncodeSfc::SetVeboxSurfaceStateParams(
     params->SurfInput.dwHeight               = m_inputSurface->dwHeight;
     params->SurfInput.dwPitch                = m_inputSurface->dwPitch;
     params->SurfInput.TileType               = m_inputSurface->TileType;
+    params->SurfInput.TileModeGMM            = m_inputSurface->TileModeGMM;
+    params->SurfInput.bGMMTileEnabled        = m_inputSurface->bGMMTileEnabled;
     params->SurfInput.dwYoffset              = m_inputSurface->YPlaneOffset.iYOffset;
     params->SurfInput.pOsResource            = &m_inputSurface->OsResource;
     params->SurfInput.rcMaxSrc.left          = m_inputSurfaceRegion.X;
@@ -664,6 +667,7 @@ MOS_STATUS CodecHalEncodeSfc::SetVeboxDiIecpParams(
     MOS_ALLOC_GFXRES_PARAMS     allocParamsForBufferLinear;
     uint32_t                    size = 0, sizeLace = 0, sizeNoLace = 0;
     MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
+    MOS_MEMCOMP_STATE           mmcMode = MOS_MEMCOMP_DISABLED;
 
     CODECHAL_ENCODE_FUNCTION_ENTER;
 
@@ -682,6 +686,19 @@ MOS_STATUS CodecHalEncodeSfc::SetVeboxDiIecpParams(
         m_osInterface,
         m_inputSurface);
 
+    m_osInterface->pfnGetMemoryCompressionMode(m_osInterface, &m_inputSurface->OsResource, &mmcMode);
+    if (mmcMode &&
+        (m_inputSurface->TileType == MOS_TILE_Y ||
+         m_inputSurface->TileType == MOS_TILE_YS))
+    {
+        m_inputSurface->bCompressible = true;
+        m_inputSurface->CompressionMode = (MOS_RESOURCE_MMC_MODE)mmcMode;
+    }
+    else
+    {
+        m_inputSurface->CompressionMode = MOS_MMC_DISABLED;
+    }
+
     params->CurInputSurfMMCState = (MOS_MEMCOMP_STATE)(m_inputSurface->CompressionMode);
 
     // Allocate Resource to avoid Page Fault issue since HW will access it
@@ -880,6 +897,8 @@ MOS_STATUS CodecHalEncodeSfc::SetSfcStateParams(
     outSurfaceParams->dwHeight             = m_sfcOutputSurface->dwHeight;
     outSurfaceParams->dwPitch              = m_sfcOutputSurface->dwPitch;
     outSurfaceParams->TileType             = m_sfcOutputSurface->TileType;
+    outSurfaceParams->TileModeGMM          = m_sfcOutputSurface->TileModeGMM;
+    outSurfaceParams->bGMMTileEnabled      = m_sfcOutputSurface->bGMMTileEnabled;
     outSurfaceParams->ChromaSiting         = m_chromaSiting;
     outSurfaceParams->dwUYoffset           = m_sfcOutputSurface->UPlaneOffset.iYOffset;
 
@@ -904,7 +923,22 @@ MOS_STATUS CodecHalEncodeSfc::SetSfcStateParams(
     params->fAlphaPixel                    = 1.0F;
     params->bColorFillEnable               = m_colorFill;
     params->bCSCEnable                     = m_CSC;
-    params->bRGBASwapEnable                = params->bCSCEnable;
+
+    // ARGB8,ABGR10,A16B16G16R16,VYUY and YVYU output format need to enable swap
+    if (m_sfcOutputSurface->Format == Format_X8R8G8B8     ||
+        m_sfcOutputSurface->Format == Format_A8R8G8B8     ||
+        m_sfcOutputSurface->Format == Format_R10G10B10A2  ||
+        m_sfcOutputSurface->Format == Format_A16B16G16R16 ||
+        m_sfcOutputSurface->Format == Format_VYUY         ||
+        m_sfcOutputSurface->Format == Format_YVYU)
+    {
+        params->bRGBASwapEnable = true;
+    }
+    else
+    {
+        params->bRGBASwapEnable = false;
+    }
+
 
     // CodecHal does not support SFC rotation
     params->RotationMode                   = MHW_ROTATION_IDENTITY;
@@ -951,7 +985,9 @@ MOS_STATUS CodecHalEncodeSfc::SetSfcAvsStateParams(
                                 m_scaleX,
                                 m_scaleY,
                                 m_chromaSiting,
-                                true));
+                                true,
+                                0,
+                                0));
     return eStatus;
 }
 
@@ -996,7 +1032,7 @@ MOS_STATUS CodecHalEncodeSfc::Initialize(
     MOS_GPUCTX_CREATOPTIONS createOption;
     //
     // VeboxgpuContext could be created from both VP and Codec.
-    // If there is no such as a GPU context it will create a new one and set the GPU component ID. 
+    // If there is no such as a GPU context it will create a new one and set the GPU component ID.
     // If there has been a valid GPU context it wont create another one anymore and the component ID wont be updated either.
     // Therefore if a codec veboxgpu context creation happens earlier than a vp veboxgpu context creation and set its component ID to MOS_GPU_COMPONENT_ENCODE,
     // VPBLT callstack would index a GpuAppTaskEvent of MOS_GPU_COMPONENT_ENCODE.
@@ -1117,8 +1153,12 @@ MOS_STATUS CodecHalEncodeSfc::RenderStart(
     MHW_VEBOX_SURFACE_STATE_CMD_PARAMS  veboxSurfaceStateCmdParams;
     MHW_VEBOX_DI_IECP_CMD_PARAMS        veboxDiIecpCmdParams;
     MHW_VEBOX_IECP_PARAMS               veboxIecpParams;
+    MHW_VEBOX_SURFACE_CNTL_PARAMS       veboxSurfCntlParams;
     MhwVeboxInterface                   *veboxInterface;
     PMHW_SFC_INTERFACE                  sfcInterface;
+    MhwMiInterface                      *miInterface;
+    PMOS_CONTEXT                        pOsContext = nullptr;
+    MHW_MI_MMIOREGISTERS                *mmioVeboxRegisters = nullptr;
     MOS_COMMAND_BUFFER                  cmdBuffer;
     bool                                requestFrameTracking;
     MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
@@ -1127,9 +1167,12 @@ MOS_STATUS CodecHalEncodeSfc::RenderStart(
 
     CODECHAL_ENCODE_CHK_NULL_RETURN(m_hwInterface);
     CODECHAL_ENCODE_CHK_NULL_RETURN(m_osInterface);
+    CODECHAL_ENCODE_CHK_NULL_RETURN(pOsContext = m_osInterface->pOsContext);
     CODECHAL_ENCODE_CHK_NULL_RETURN(encoder);
     CODECHAL_ENCODE_CHK_NULL_RETURN(sfcInterface = m_hwInterface->GetSfcInterface());
     CODECHAL_ENCODE_CHK_NULL_RETURN(veboxInterface = m_hwInterface->GetVeboxInterface());
+    CODECHAL_ENCODE_CHK_NULL_RETURN(miInterface = m_hwInterface->GetMiInterface());
+    CODECHAL_ENCODE_CHK_NULL_RETURN(mmioVeboxRegisters = miInterface->GetMmioRegisters());
 
     // Switch GPU context to VEBOX
     m_osInterface->pfnSetGpuContext(m_osInterface, MOS_GPU_CONTEXT_VEBOX);
@@ -1144,6 +1187,23 @@ MOS_STATUS CodecHalEncodeSfc::RenderStart(
     requestFrameTracking = false;
     CODECHAL_ENCODE_CHK_STATUS_RETURN(encoder->SendPrologWithFrameTracking(&cmdBuffer, requestFrameTracking));
 
+    // If m_pollingSyncEnabled is set, insert HW semaphore to wait for external
+    // raw surface processing to complete, before start CSC. Once the marker in
+    // raw surface is overwritten by external operation, HW semaphore will be
+    // signalled and CSC will start. This is to reduce SW latency between
+    // external raw surface processing and CSC, in usages like remote gaming.
+    if (encoder->m_pollingSyncEnabled)
+    {
+        MHW_MI_SEMAPHORE_WAIT_PARAMS miSemaphoreWaitParams;
+        MOS_ZeroMemory((&miSemaphoreWaitParams), sizeof(miSemaphoreWaitParams));
+        miSemaphoreWaitParams.presSemaphoreMem = &m_inputSurface->OsResource;
+        miSemaphoreWaitParams.dwResourceOffset = encoder->m_syncMarkerOffset;
+        miSemaphoreWaitParams.bPollingWaitMode = true;
+        miSemaphoreWaitParams.dwSemaphoreData  = encoder->m_syncMarkerValue;
+        miSemaphoreWaitParams.CompareOperation = MHW_MI_SAD_NOT_EQUAL_SDD;
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(miInterface->AddMiSemaphoreWaitCmd(&cmdBuffer, &miSemaphoreWaitParams));
+    }
+
     // Setup cmd prameters
     MOS_ZeroMemory(&veboxStateCmdParams, sizeof(veboxStateCmdParams));
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetVeboxStateParams(&veboxStateCmdParams));
@@ -1154,6 +1214,13 @@ MOS_STATUS CodecHalEncodeSfc::RenderStart(
     MOS_ZeroMemory(&veboxDiIecpCmdParams, sizeof(veboxDiIecpCmdParams));
     CODECHAL_ENCODE_CHK_STATUS_RETURN(SetVeboxDiIecpParams(&veboxDiIecpCmdParams));
 
+    MOS_ZeroMemory(&veboxSurfCntlParams, sizeof(veboxSurfCntlParams));
+    veboxSurfCntlParams.bIsCompressed   = m_inputSurface->bIsCompressed;
+    veboxSurfCntlParams.CompressionMode = m_inputSurface->CompressionMode;
+    CODECHAL_ENCODE_CHK_STATUS_RETURN(veboxInterface->AddVeboxSurfaceControlBits(
+        &veboxSurfCntlParams,
+        (uint32_t *)&(veboxDiIecpCmdParams.CurrInputSurfCtrl.Value)));
+
     // get csc matrix
     MOS_ZeroMemory(&veboxIecpParams, sizeof(veboxIecpParams));
     CODECHAL_ENCODE_CHK_STATUS_RETURN(VeboxSetIecpParams(&veboxIecpParams));
@@ -1169,8 +1236,20 @@ MOS_STATUS CodecHalEncodeSfc::RenderStart(
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(AddSfcCommands(sfcInterface, &cmdBuffer));
 
+    HalOcaInterface::OnDispatch(cmdBuffer, *pOsContext, *miInterface, *mmioVeboxRegisters);
+
     CODECHAL_ENCODE_CHK_STATUS_RETURN(veboxInterface->AddVeboxDiIecp(&cmdBuffer, &veboxDiIecpCmdParams));
 
+    // If m_pollingSyncEnabled is set, write the marker to source surface for next MI_SEMAPHORE_WAIT to check.
+    if (encoder->m_pollingSyncEnabled)
+    {
+        MHW_MI_STORE_DATA_PARAMS storeDataParams;
+        storeDataParams.pOsResource      = &m_inputSurface->OsResource;
+        storeDataParams.dwResourceOffset = encoder->m_syncMarkerOffset;
+        storeDataParams.dwValue          = encoder->m_syncMarkerValue;
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(miInterface->AddMiStoreDataImmCmd(&cmdBuffer, &storeDataParams));
+    }
+
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_hwInterface->GetMiInterface()->AddMiBatchBufferEnd(
         &cmdBuffer,
         nullptr));
@@ -1181,6 +1260,8 @@ MOS_STATUS CodecHalEncodeSfc::RenderStart(
         nullptr)));
 
     m_osInterface->pfnReturnCommandBuffer(m_osInterface, &cmdBuffer, 0);
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
         m_osInterface,
         &cmdBuffer,
