@@ -42,7 +42,9 @@ class MhwCpInterface;
 #define MHW_MI_ENCODER_8K_WATCHDOG_THRESHOLD_IN_MS      500
 #define MHW_MI_ENCODER_4K_WATCHDOG_THRESHOLD_IN_MS      100
 #define MHW_MI_ENCODER_FHD_WATCHDOG_THRESHOLD_IN_MS     50
+#define MHW_MI_DECODER_720P_WATCHDOG_THRESHOLD_IN_MS    10
 #define MHW_MI_DECODER_16K_WATCHDOG_THRESHOLD_IN_MS     180
+#define MHW_MI_DECODER_16Kx16K_WATCHDOG_THRESHOLD_IN_MS 256
 #define MHW_MI_WATCHDOG_COUNTS_PER_MILLISECOND         (19200123 / 1000)   // Time stamp counts per millisecond
 
 typedef enum _MHW_COMMON_MI_ADDRESS_SHIFT
@@ -729,7 +731,7 @@ protected:
     MOS_STATUS (*AddResourceToCmd) (
         PMOS_INTERFACE                  pOsInterface,
         PMOS_COMMAND_BUFFER             cmdBuffer,
-        PMHW_RESOURCE_PARAMS            params);
+        PMHW_RESOURCE_PARAMS            params) = nullptr;
 
     //!
     //! \brief    Helper function to get GTT type (PGTT or GGTT)
@@ -758,7 +760,7 @@ protected:
     } MediaResetParam;
 
     //! \brief Mmio registers address
-    MHW_MI_MMIOREGISTERS       m_mmioRegisters;  //!< mfx mmio registers
+    MHW_MI_MMIOREGISTERS       m_mmioRegisters = {};  //!< mfx mmio registers
 
 };
 
