@@ -21,7 +21,7 @@
 */
 //!
 //! \file     mhw_vebox.h
-//! \brief    MHW interface for constructing commands for the VEBOX 
+//! \brief    MHW interface for constructing commands for the VEBOX
 //! \details  Impelements the functionalities common across all platforms for MHW_VEBOX
 //!
 
@@ -126,9 +126,10 @@ typedef enum _MHW_GAMUT_MODE
 {
     MHW_GAMUT_MODE_NONE,
     MHW_GAMUT_MODE_BASIC,
-    MHW_GAMUT_MODE_ADVANCED
+    MHW_GAMUT_MODE_ADVANCED,
+    MHW_GAMUT_MODE_CUSTOMIZED
 } MHW_GAMUT_MODE;
-C_ASSERT(MHW_GAMUT_MODE_ADVANCED == 2);
+C_ASSERT(MHW_GAMUT_MODE_CUSTOMIZED == 3);
 
 //!
 //! \brief Gamma Values configuration enum
@@ -543,7 +544,7 @@ typedef struct _MHW_CAPPIPE_PARAMS
 } MHW_CAPPIPE_PARAMS, *PMHW_CAPPIPE_PARAMS;
 
 //!
-//! Structure MHW_3DLUT_PARAMS 
+//! Structure MHW_3DLUT_PARAMS
 //! \details No pre-si version for MHW_VEBOX_IECP_PARAMS, just leave it now and handle it later
 //!
 typedef struct _MHW_3DLUT_PARAMS
@@ -554,16 +555,16 @@ typedef struct _MHW_3DLUT_PARAMS
     uint8_t *pLUT;                       //!< Pointer to the LUT value
 } MHW_3DLUT_PARAMS, *PMHW_3DLUT_PARAMS;
 
-//! 
+//!
 //! \brief  VEBOX HDR PARAMS
 //! \details For CCM settings, move 1DLut to here later
 typedef struct _MHW_1DLUT_PARAMS
 {
     uint32_t bActive;
-    uint32_t *p1DLUT;
-    uint32_t *LUTSize;
+    void     *p1DLUT;
+    uint32_t LUTSize;
     int32_t *pCCM;
-    uint32_t *CCMSize;
+    uint32_t CCMSize;
 } MHW_1DLUT_PARAMS, *PMHW_1DLUT_PARAMS;
 
 //!
@@ -648,6 +649,14 @@ typedef struct _MHW_VEBOX_GAMUT_PARAMS
 
     // GExp
     MHW_GAMUT_MODE                      GExpMode;
+    uint32_t                            *pFwdGammaBias;
+    uint32_t                            *pInvGammaBias;
+    float                               *pfCscCoeff;         // [3x3] CSC Coeff matrix
+    float                               *pfCscInOffset;      // [3x1] CSC Input Offset matrix
+    float                               *pfCscOutOffset;     // [3x1] CSC Output Offset matrix
+    float                               *pfFeCscCoeff;       // [3x3] Front-end CSC Coeff matrix
+    float                               *pfFeCscInOffset;    // [3x1] Front-end CSC Input Offset matrix
+    float                               *pfFeCscOutOffset;   // [3x1] Front-end CSC Output Offset matrix
     int32_t                             Matrix[3][3];
 
     // Gamma correction
@@ -707,16 +716,19 @@ typedef struct _MHW_VEBOX_SURFACE_PARAMS
 {
     uint32_t                    bActive;
     bool                        bIsCompressed;
-    MOS_FORMAT                  Format;             //!<  Surface format
-    uint32_t                    dwWidth;            //!<  Surface width
-    uint32_t                    dwHeight;           //!<  Surface height
-    uint32_t                    dwPitch;            //!<  Surface pitch
-    uint32_t                    dwBitDepth;         //!<  Surface bitdepth
-    uint32_t                    dwStreamID;         //!<  Surface StreamID
-    uint32_t                    dwYoffset;          //!<  Surface Yoffset in Vertical
-    uint32_t                    dwUYoffset;         //!<  Surface Uoffset in Vertical
-    MOS_TILE_TYPE               TileType;           //!<  Tile Type
-    RECT                        rcMaxSrc;           //!< Max source rectangle
+    MOS_FORMAT                  Format;              //!<  Surface format
+    uint32_t                    dwCompressionFormat; //!<  Surface Compression Format
+    uint32_t                    dwWidth;             //!<  Surface width
+    uint32_t                    dwHeight;            //!<  Surface height
+    uint32_t                    dwPitch;             //!<  Surface pitch
+    uint32_t                    dwBitDepth;          //!<  Surface bitdepth
+    uint32_t                    dwStreamID;          //!<  Surface StreamID
+    uint32_t                    dwYoffset;           //!<  Surface Yoffset in Vertical
+    uint32_t                    dwUYoffset;          //!<  Surface Uoffset in Vertical
+    MOS_TILE_TYPE               TileType;            //!<  Tile Type
+    MOS_TILE_MODE_GMM           TileModeGMM;         //!<  Tile Mode from GMM Definition
+    bool                        bGMMTileEnabled;     //!<  GMM defined tile mode flag
+    RECT                        rcMaxSrc;            //!< Max source rectangle
     PMOS_RESOURCE               pOsResource;         //!<  Surface resource
 } MHW_VEBOX_SURFACE_PARAMS, *PMHW_VEBOX_SURFACE_PARAMS;
 
@@ -1014,6 +1026,21 @@ public:
 protected:
     MhwVeboxInterface(PMOS_INTERFACE pOsInterface);
 
+    //!
+    //! \brief    Trace indirect state info by OCA
+    //! \details  Trace which resource being used to store indirect state by OCA.
+    //! \param    [in] cmdBuffer
+    //!           Command buffer of current vebox workload.
+    //! \param    [in] mosContext
+    //!           mos context
+    //! \param    [in] isCmBuffer
+    //!           true if CM buffer being used for indirect state, otherwise, vebox heap is used.
+    //! \param    [in] useVeboxHeapKernelResource
+    //!           true if kernel copy needed for indirect state.
+    //! \return   void
+    //!
+    void TraceIndirectStateInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT &mosContext, bool isCmBuffer, bool useVeboxHeapKernelResource);
+
 public:
     //!
     //! \brief    Adds a resource to the command buffer or indirect state (SSH)
@@ -1047,7 +1074,7 @@ public:
     //!
     //!      GPU (Driver Resource)      GPU (Kernel Resource)        VEBOX State (in Graphics Memory)
     //!      -------------------         -------------------        ---------------------
-    //!     | VEBOX State 0     |       | VEBOX State 0     |       | DNDI State         | 
+    //!     | VEBOX State 0     |       | VEBOX State 0     |       | DNDI State         |
     //!      -------------------         -------------------         --------------------
     //!     | VEBOX State 1     |       | VEBOX State 1     |       | IECP State         |
     //!      -------------------         -------------------         --------------------
@@ -1056,7 +1083,7 @@ public:
     //!     | VEBOX Sync Data   |       | VEBOX Sync Data   |       | Vertex State       |
     //!      -------------------                                     --------------------
     //!                                                             | CapturePipe State  |
-    //!                                                              -------------------- 
+    //!                                                              --------------------
     //!                                                             | Gamma Correction State |
     //!                                                              ------------------------
     //!                                                             | 3D LUT State           |
