@@ -31,6 +31,8 @@
 #include "mhw_utilities.h"
 #include "cm_def.h"
 #include "renderhal_platform_interface.h"
+#include "hal_oca_interface.h"
+#include "mhw_mmio_g11.h"
 #if defined(ENABLE_KERNELS) && (!defined(_FULL_OPEN_SOURCE))
 #include "cm_gpucopy_kernel_g11lp.h"
 #include "cm_gpuinit_kernel_g11lp.h"
@@ -125,70 +127,24 @@ MOS_STATUS CM_HAL_G11_X::SetMediaWalkerParams(
 }
 
 MOS_STATUS CM_HAL_G11_X::HwSetSurfaceMemoryObjectControl(
-                    uint16_t                        memObjCtl,
-                    PRENDERHAL_SURFACE_STATE_PARAMS surfStateParams)
+    uint16_t                        memObjCtl,
+    PRENDERHAL_SURFACE_STATE_PARAMS surfStateParams)
 {
     PRENDERHAL_INTERFACE renderHal = m_cmState->renderHal;
-    MOS_STATUS hr = MOS_STATUS_SUCCESS;
-
-    CM_HAL_MEMORY_OBJECT_CONTROL_G9 cacheType;
-
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    MOS_HW_RESOURCE_DEF mosUsage;
     // The memory object control uint16_t is composed with cache type(8:15), memory type(4:7), ages(0:3)
+    mosUsage = (MOS_HW_RESOURCE_DEF)((memObjCtl & CM_MEMOBJCTL_CACHE_MASK) >> 8);
+    if (mosUsage >= MOS_HW_RESOURCE_DEF_MAX)
+        mosUsage = GetDefaultMOCS();
 
-    cacheType = (CM_HAL_MEMORY_OBJECT_CONTROL_G9)((memObjCtl & CM_MEMOBJCTL_CACHE_MASK) >> 8);
+    surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(mosUsage,
+        renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
 
-    if ((uint16_t)cacheType == CM_INVALID_MEMOBJCTL)
-        cacheType = CM_MEMORY_OBJECT_CONTROL_SKL_DEFAULT;
-
-    switch (cacheType)
-    {
-    case CM_MEMORY_OBJECT_CONTROL_SKL_DEFAULT:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_L3:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_L3_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_LLC_ELLC:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_LLC_ELLC_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_LLC:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_LLC_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_ELLC:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_ELLC_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_LLC_L3:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_LLC_L3_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_ELLC_L3:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_ELLC_L3_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    case CM_MEMORY_OBJECT_CONTROL_SKL_NO_CACHE:
-        surfStateParams->MemObjCtl = renderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
-            MOS_CM_RESOURCE_USAGE_NO_CACHE_SurfaceState,
-            renderHal->pOsInterface->pfnGetGmmClientContext(renderHal->pOsInterface)).DwordValue;
-        break;
-    default:
-        hr = MOS_STATUS_UNKNOWN;
-    }
-
-    return MOS_STATUS_SUCCESS;
+    return eStatus;
 }
 
+
 MOS_STATUS CM_HAL_G11_X::RegisterSampler8x8AVSTable(
                    PCM_HAL_SAMPLER_8X8_TABLE  sampler8x8AvsTable,
                    PCM_AVS_TABLE_STATE_PARAMS avsTable)
@@ -397,12 +353,19 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
     bool                         sipEnable = renderHal->bSIPKernel?true: false;
     bool                         csrEnable = renderHal->bCSRKernel?true: false;
     RENDERHAL_GENERIC_PROLOG_PARAMS genericPrologParams = {};
-    MOS_RESOURCE                 osResource;
+    MOS_RESOURCE                 *osResource;
     uint32_t                     tag;
+    uint32_t                     tagOffset = 0;
     MHW_RENDER_ENGINE_L3_CACHE_SETTINGS_G11 cacheSettings = {};
+    MOS_CONTEXT                  *pOsContext = renderHal->pOsInterface->pOsContext;
+    PMHW_MI_MMIOREGISTERS        pMmioRegisters = renderHal->pMhwRenderInterface->GetMmioRegisters();
+    CM_HAL_MI_REG_OFFSETS        miRegG11 = { REG_TIMESTAMP_BASE_G11, REG_GPR_BASE_G11 };
 
     MOS_ZeroMemory(&mosCmdBuffer, sizeof(MOS_COMMAND_BUFFER));
 
+    // get the tag
+    tag = renderHal->trackerProducer.GetNextTracker(renderHal->currentTrackerIndex);
+
     // Get the task sync offset
     syncOffset = state->pfnGetTaskSyncLocation(state, taskId);
 
@@ -412,7 +375,8 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
     *(taskSyncLocation + 1) = CM_INVALID_INDEX;
     if (state->cbbEnabled)
     {
-        *(taskSyncLocation + 2) = renderHal->trackerResource.currentTrackerId;
+        *(taskSyncLocation + 2) = tag;
+        *(taskSyncLocation + 3) = state->renderHal->currentTrackerIndex;
     }
 
     // Register batch buffer for rendering
@@ -440,12 +404,11 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
     CM_CHK_MOSSTATUS_GOTOFINISH(state->pfnUpdatePowerOption(state, &state->powerOption));
 
     // use frame tracking to write the tracker ID to CM tracker resource
-    osResource = renderHal->trackerResource.osResource;
-    tag        = renderHal->trackerResource.currentTrackerId;
+    renderHal->trackerProducer.GetLatestTrackerResource(renderHal->currentTrackerIndex, &osResource, &tagOffset);
+    renderHal->pfnSetupPrologParams(renderHal, &genericPrologParams, osResource, tagOffset, tag);
+    FrameTrackerTokenFlat_SetProducer(&stateHeap->pCurMediaState->trackerToken, &renderHal->trackerProducer);
+    FrameTrackerTokenFlat_Merge(&stateHeap->pCurMediaState->trackerToken, renderHal->currentTrackerIndex, tag);
 
-    renderHal->pfnSetupPrologParams(renderHal, &genericPrologParams, &osResource, tag);
-    stateHeap->pCurMediaState->dwSyncTag = tag;
-    
     // Record registers by unified media profiler in the beginning
     if (state->perfProfiler != nullptr)
     {
@@ -462,9 +425,12 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
 
     // Initialize command buffer and insert prolog
     CM_CHK_MOSSTATUS_GOTOFINISH(renderHal->pfnInitCommandBuffer(renderHal, &mosCmdBuffer, &genericPrologParams));
+    
+    HalOcaInterface::On1stLevelBBStart(mosCmdBuffer, *pOsContext, osInterface->CurrentGpuContextHandle,
+        *renderHal->pMhwMiInterface, *pMmioRegisters);
 
     // update tracker tag used with CM tracker resource
-    renderHal->pfnIncTrackerId(state->renderHal);
+    renderHal->trackerProducer.StepForward(renderHal->currentTrackerIndex);
 
     // Increment sync tag
     syncTag = stateHeap->dwNextTag++;
@@ -639,6 +605,8 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
     idLoadParams.pKernelState = nullptr;
     CM_CHK_MOSSTATUS_GOTOFINISH( mhwRender->AddMediaIDLoadCmd(&mosCmdBuffer, &idLoadParams ) );
 
+    HalOcaInterface::OnDispatch(mosCmdBuffer, *pOsContext, *renderHal->pMhwMiInterface, *pMmioRegisters);
+
     if ( enableWalker )
     {
         // send media walker command, if required
@@ -652,21 +620,8 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
 
                 CM_CHK_MOSSTATUS_GOTOFINISH( renderHal->pfnSendSyncTag( renderHal, &mosCmdBuffer ) );
 
-                // Insert a pipe control for synchronization since this Conditional Batch Buffer End command
-                // will use value written by previous kernel. Also needed since this may be the Batch Buffer End
-                pipeCtlParams = g_cRenderHal_InitPipeControlParams;
-                pipeCtlParams.presDest = &state->renderTimeStampResource.osResource;
-                pipeCtlParams.dwPostSyncOp = MHW_FLUSH_NOWRITE;
-                pipeCtlParams.dwFlushMode = MHW_FLUSH_WRITE_CACHE;
-                CM_CHK_MOSSTATUS_GOTOFINISH(mhwMiInterface->AddPipeControl(&mosCmdBuffer, nullptr, &pipeCtlParams ) );
-
-                // issue a PIPE_CONTROL to write timestamp
-                pipeCtlParams = g_cRenderHal_InitPipeControlParams;
-                pipeCtlParams.presDest = &state->renderTimeStampResource.osResource;
-                pipeCtlParams.dwResourceOffset = syncOffset + sizeof( uint64_t );
-                pipeCtlParams.dwPostSyncOp = MHW_FLUSH_WRITE_TIMESTAMP_REG;
-                pipeCtlParams.dwFlushMode = MHW_FLUSH_READ_CACHE;
-                CM_CHK_MOSSTATUS_GOTOFINISH(mhwMiInterface->AddPipeControl(&mosCmdBuffer, nullptr, &pipeCtlParams ) );
+                // conditionally write timestamp
+                CM_CHK_MOSSTATUS_GOTOFINISH(HalCm_OsAddArtifactConditionalPipeControl(&miRegG11, state, &mosCmdBuffer, syncOffset, &taskParam->conditionalBBEndParams[i], tag));
 
                 // Insert conditional batch buffer end
                 mhwMiInterface->AddMiConditionalBatchBufferEndCmd(&mosCmdBuffer, &taskParam->conditionalBBEndParams[ i ] );
@@ -769,12 +724,12 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
     pipeCtlParams.dwFlushMode = MHW_FLUSH_WRITE_CACHE;
     CM_CHK_MOSSTATUS_GOTOFINISH( mhwMiInterface->AddPipeControl( &mosCmdBuffer, nullptr, &pipeCtlParams ) );
 
-    if (state->svmBufferUsed)
+    if (state->svmBufferUsed || state->statelessBufferUsed)
     {
         // Find the SVM slot, patch it into this dummy pipe_control
         for (uint32_t i = 0; i < state->cmDeviceParam.maxBufferTableSize; i++ )
         {
-            //Only register SVM resource here
+            //register resource here
             if ( state->bufferTable[ i ].address )
             {
                 CM_CHK_HRESULT_GOTOFINISH_MOSERROR( osInterface->pfnRegisterResource(
@@ -783,6 +738,17 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
                     true,
                     false ) );
             }
+
+            // sync resource
+            MOS_SURFACE mosSurface;
+            MOS_ZeroMemory(&mosSurface, sizeof(mosSurface));
+            CM_CHK_HRESULT_GOTOFINISH_MOSERROR(osInterface->pfnGetResourceInfo(
+                osInterface,
+                &state->bufferTable[i].osResource,
+                &mosSurface));
+            mosSurface.OsResource = state->bufferTable[i].osResource;
+
+            CM_CHK_HRESULT_GOTOFINISH_MOSERROR(HalCm_SurfaceSync(state, &mosSurface, false));
         }
     }
 
@@ -820,6 +786,7 @@ MOS_STATUS CM_HAL_G11_X::SubmitCommands(
     pipeControlParams.bDisableCSStall = false;
     CM_CHK_MOSSTATUS_GOTOFINISH(mhwMiInterface->AddPipeControl(&mosCmdBuffer, nullptr, &pipeControlParams));
 
+    HalOcaInterface::On1stLevelBBEnd(mosCmdBuffer, *pOsContext);
     //Couple to the BB_START , otherwise GPU Hang without it
     CM_CHK_MOSSTATUS_GOTOFINISH(mhwMiInterface->AddMiBatchBufferEnd(&mosCmdBuffer, nullptr ) );
 
