@@ -159,22 +159,10 @@ MOS_STATUS CodechalKernelHmeG11::SetCurbe(MHW_KERNEL_STATE *kernelState)
     }
 
     // r3 & r4
-    uint8_t methodIndex;
-    if (m_pictureCodingType == B_TYPE)
-    {
-        CODECHAL_ENCODE_CHK_NULL_RETURN(m_bmeMethodTable);
-        methodIndex = m_curbeParam.bmeMethodTable ?
-            m_curbeParam.bmeMethodTable[m_curbeParam.targetUsage] : m_bmeMethodTable[m_curbeParam.targetUsage];
-    }
-    else
-    {
-        CODECHAL_ENCODE_CHK_NULL_RETURN(m_meMethodTable);
-        methodIndex = m_curbeParam.meMethodTable ?
-            m_curbeParam.meMethodTable[m_curbeParam.targetUsage] : m_meMethodTable[m_curbeParam.targetUsage];
-    }
+    uint8_t methodIndex = 0; // kernel requirement
+    uint8_t tableIndex  = (m_pictureCodingType == B_TYPE) ? 1 : 0;
 
-    uint8_t tableIndex = (m_pictureCodingType == B_TYPE) ? 1 : 0;
-    MOS_SecureMemcpy(&curbe.m_data.SpDelta, 14 * sizeof(uint32_t), codechalEncodeSearchPath[tableIndex][0], 14 * sizeof(uint32_t));  //methodIndex set to 0 as per kernel requirement
+    MOS_SecureMemcpy(&curbe.m_data.SpDelta, 14 * sizeof(uint32_t), codechalEncodeSearchPath[tableIndex][methodIndex], 14 * sizeof(uint32_t));
 
     // Non legacy stream in is for hevc vp9 streamin kernel
     if (m_4xMeInUse && m_useNonLegacyStreamIn)
@@ -377,6 +365,7 @@ MOS_STATUS CodechalKernelHmeG11::SendSurfaces(PMOS_COMMAND_BUFFER cmd, MHW_KERNE
             surfaceParams.bIs2DSurface = true;
             surfaceParams.bMediaBlockRW = true;
             surfaceParams.psSurface = GetSurface(SurfaceId::me4xDistortionBuffer);
+            surfaceParams.psSurface->dwHeight = m_surfaceParam.downScaledHeightInMb * 4 * 10;
             surfaceParams.dwOffset = m_meDistortionBottomFieldOffset;
             surfaceParams.dwBindingTableOffset = BindingTableOffset::meDistortionSurface;
             surfaceParams.dwCacheabilityControl = m_hwInterface->GetCacheabilitySettings()[MOS_CODEC_RESOURCE_USAGE_SURFACE_ME_DISTORTION_ENCODE].Value;
