@@ -923,6 +923,8 @@ public:
         uint8_t   RSVD[16];
     };
 
+    // Delay between semaphore(barrier) wait and reset
+    static constexpr uint32_t m_numDelay = 15;
     // VDENC BRC related buffer size
     static constexpr uint32_t m_brcStatsBufSize = ((48 + 256) * sizeof(uint32_t));        // 48 DWs of statistics data at the end of every tile that will be used by the BRC kernel. 64 byte aligned. 256 DWs of Histogram data at an offset of 3 CLs (48 DWs)
     static constexpr uint32_t m_brcPakStatsBufSize = (64 * sizeof(uint32_t));
@@ -953,7 +955,7 @@ public:
 
     // Stats Integration regions
     CODECHAL_ENCODE_BUFFER                      m_hcpScalabilitySyncBuffer;
-    CODECHAL_ENCODE_BUFFER                      m_hcpTileSizeStreamoutBuffer[m_numUncompressedSurface];
+    CODECHAL_ENCODE_BUFFER                      m_tileRecordBuffer[m_numUncompressedSurface];
     CODECHAL_ENCODE_BUFFER                      m_tileStatsPakIntegrationBuffer[m_numUncompressedSurface];
     uint32_t                                    m_tileStatsPakIntegrationBufferSize = 0;
     CODECHAL_ENCODE_BUFFER                      m_frameStatsPakIntegrationBuffer;
@@ -962,13 +964,14 @@ public:
     MHW_VDBOX_HUC_VIRTUAL_ADDR_PARAMS           m_hpuVirtualAddrParams;
     MOS_RESOURCE                                m_hucPakIntDummyBuffer;
     MOS_RESOURCE                                m_hucPakIntBrcDataBuffer;
-    StatsInfo                                   m_tileStatsOffset;  // Page aligned offsets for HuC PAK Integration kernel input
-    StatsInfo                                   m_frameStatsOffset; // Page aligned offsets for HuC PAK Integration kernel output
-    StatsInfo                                   m_statsSize;        // Sizes for the stats for HuC PAK Integration kernel input
+    StatsInfo                                   m_tileStatsOffset = {};  // Page aligned offsets for HuC PAK Integration kernel input
+    StatsInfo                                   m_frameStatsOffset = {}; // Page aligned offsets for HuC PAK Integration kernel output
+    StatsInfo                                   m_statsSize = {};        // Sizes for the stats for HuC PAK Integration kernel input
     // Semaphore memory for synchronizing
-    CODECHAL_ENCODE_BUFFER                      m_hucDoneSemaphoreMem[m_maxNumPipes];
+    MOS_RESOURCE                                m_resPipeStartSync;
+    MOS_RESOURCE                                m_resFrameStartSync = {};
     CODECHAL_ENCODE_BUFFER                      m_stitchWaitSemaphoreMem[m_maxNumPipes];
-    CODECHAL_ENCODE_BUFFER                      m_pakIntDoneSemaphoreMem;
+    MOS_RESOURCE                                m_resDelayMinus;
     uint16_t                                    m_lastVdencPictureState2ndLevelBBIndex = 0;
 
     PMHW_VDBOX_HCP_TILE_CODING_PARAMS_G11 m_tileParams = nullptr;  //!< Pointer to the Tile params
@@ -1057,7 +1060,8 @@ public:
 
     MOS_STATUS SendPrologWithFrameTracking(
         PMOS_COMMAND_BUFFER cmdBuffer,
-        bool frameTrackingRequested);
+        bool frameTrackingRequested,
+        MHW_MI_MMIOREGISTERS *mmioRegister = nullptr);
 
     MOS_STATUS SetSemaphoreMem(
         PMOS_RESOURCE semaphoreMem,
@@ -1066,6 +1070,13 @@ public:
 
     MOS_STATUS UserFeatureKeyReport();
 
+    MOS_STATUS SendMIAtomicCmd(
+        PMOS_RESOURCE               semaMem,
+        uint32_t                    immData,
+        MHW_COMMON_MI_ATOMIC_OPCODE opCode,
+        PMOS_COMMAND_BUFFER         cmdBuffer
+    );
+
     MOS_STATUS SendHWWaitCommand(
         PMOS_RESOURCE semaphoreMem,
         PMOS_COMMAND_BUFFER cmdBuffer,
@@ -1115,8 +1126,6 @@ public:
 
     MOS_STATUS SetupSegmentationStreamIn();
 
-    PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS CreateMhwVdboxPipeModeSelectParams();
-
     void SetHcpPipeModeSelectParams(MHW_VDBOX_PIPE_MODE_SELECT_PARAMS& pipeModeSelectParams);
 
     void SetHcpIndObjBaseAddrParams(MHW_VDBOX_IND_OBJ_BASE_ADDR_PARAMS& indObjBaseAddrParams);
