@@ -726,7 +726,6 @@ MOS_STATUS MHW_STATE_HEAP_INTERFACE_G9_X::SetSamplerState(
         Cmd.DW0.MinModeFilter = Cmd.MIN_MODE_FILTER_LINEAR;
         Cmd.DW0.MagModeFilter = Cmd.MAG_MODE_FILTER_LINEAR;
         Cmd.DW0.TextureBorderColorMode = Cmd.TEXTURE_BORDER_COLOR_MODE_8BIT;
-        Cmd.DW0.SamplerDisable = true;
         Cmd.DW1.ShadowFunction = Cmd.SHADOW_FUNCTION_PREFILTEROPNEVER;
         Cmd.DW3.TczAddressControlMode = Cmd.TCZ_ADDRESS_CONTROL_MODE_CLAMP;
         Cmd.DW3.TcyAddressControlMode = Cmd.TCY_ADDRESS_CONTROL_MODE_CLAMP;
@@ -771,7 +770,7 @@ MOS_STATUS MHW_STATE_HEAP_INTERFACE_G9_X::SetSamplerState(
             UnormSamplerInit.DW0.MinModeFilter = UnormSamplerInit.MIN_MODE_FILTER_LINEAR;
             UnormSamplerInit.DW0.MagModeFilter = UnormSamplerInit.MAG_MODE_FILTER_LINEAR;
             UnormSamplerInit.DW0.TextureBorderColorMode = UnormSamplerInit.TEXTURE_BORDER_COLOR_MODE_8BIT;
-            UnormSamplerInit.DW0.SamplerDisable = true;
+            UnormSamplerInit.DW0.SamplerDisable = false;
             UnormSamplerInit.DW1.ShadowFunction = UnormSamplerInit.SHADOW_FUNCTION_PREFILTEROPNEVER;
             UnormSamplerInit.DW3.TczAddressControlMode = UnormSamplerInit.TCZ_ADDRESS_CONTROL_MODE_CLAMP;
             UnormSamplerInit.DW3.TcyAddressControlMode = UnormSamplerInit.TCY_ADDRESS_CONTROL_MODE_CLAMP;
@@ -785,8 +784,6 @@ MOS_STATUS MHW_STATE_HEAP_INTERFACE_G9_X::SetSamplerState(
 
             *pUnormSampler = UnormSamplerInit;
 
-            pUnormSampler->DW0.SamplerDisable = false;
-
             if (pParam->Unorm.SamplerFilterMode == MHW_SAMPLER_FILTER_NEAREST)
             {
                 pUnormSampler->DW0.MinModeFilter = pUnormSampler->MIN_MODE_FILTER_NEAREST;
