@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2018, Intel Corporation
+* Copyright (c) 2009-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -38,6 +38,10 @@
 #include "mos_gpucontextmgr.h"
 #include "mos_cmdbufmgr.h"
 
+#include "mos_context_next.h"
+#include "mos_gpucontextmgr_next.h"
+#include "mos_cmdbufmgr_next.h"
+
 #include "mos_os.h"
 #include "mos_auxtable_mgr.h"
 
@@ -152,6 +156,8 @@ typedef enum _DDI_MEDIA_FORMAT
     Media_Format_R5G6B5      ,
     Media_Format_R10G10B10A2 ,
     Media_Format_B10G10R10A2 ,
+    Media_Format_R10G10B10X2 ,
+    Media_Format_B10G10R10X2 ,
     Media_Format_CPU         ,
 
     Media_Format_YUY2        ,
@@ -170,6 +176,7 @@ typedef enum _DDI_MEDIA_FORMAT
     Media_Format_P010        ,
     Media_Format_R8G8B8      ,
     Media_Format_RGBP        ,
+    Media_Format_BGRP        ,
 
     Media_Format_P016        ,
     Media_Format_Y210        ,
@@ -177,16 +184,22 @@ typedef enum _DDI_MEDIA_FORMAT
     Media_Format_AYUV        ,
     Media_Format_Y410        ,
     Media_Format_Y416        ,
-
+    Media_Format_Y8          ,
+    Media_Format_Y16S        ,
+    Media_Format_Y16U        ,
+    Media_Format_VYUY        ,
+    Media_Format_YVYU        ,
+    Media_Format_A16R16G16B16,
+    Media_Format_A16B16G16R16,
     Media_Format_Count
 } DDI_MEDIA_FORMAT;
 
 typedef enum _DDI_MEDIA_STATUS_REPORT_QUERY_STATE
 {
-    DDI_MEDIA_STATUS_REPORT_QUREY_STATE_INIT,
-    DDI_MEDIA_STATUS_REPORT_QUREY_STATE_PENDING,
-    DDI_MEDIA_STATUS_REPORT_QUREY_STATE_COMPLETED,
-    DDI_MEDIA_STATUS_REPORT_QUREY_STATE_RELEASED
+    DDI_MEDIA_STATUS_REPORT_QUERY_STATE_INIT,
+    DDI_MEDIA_STATUS_REPORT_QUERY_STATE_PENDING,
+    DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED,
+    DDI_MEDIA_STATUS_REPORT_QUERY_STATE_RELEASED
 } DDI_MEDIA_STATUS_REPORT_QUERY_STATE;
 
 //!
@@ -424,6 +437,9 @@ struct DDI_MEDIA_CONTEXT
     GpuContextMgr      *m_gpuContextMgr;
     CmdBufMgr          *m_cmdBufMgr;
 
+    // Apogeio MOS module
+    MOS_DEVICE_HANDLE   m_osDeviceContext = MOS_INVALID_HANDLE;
+
     // mutexs to protect the shared resource among multiple context
     MEDIA_MUTEX_T       SurfaceMutex;
     MEDIA_MUTEX_T       BufferMutex;
@@ -445,6 +461,28 @@ struct DDI_MEDIA_CONTEXT
         PMOS_CONTEXT  pMosCtx,
         PMOS_RESOURCE pOsResource);
 
+    //!
+    //! \brief  the function ptr for surface copy function
+    //!
+    void  (* pfnMediaMemoryCopy )(
+        PMOS_CONTEXT       pMosCtx,
+        PMOS_RESOURCE      pInputResource,
+        PMOS_RESOURCE      pOutputResource,
+        bool               bOutputCompressed);
+
+    //!
+    //! \brief  the function ptr for Media Memory 2D copy function
+    //!
+    void (* pfnMediaMemoryCopy2D)(
+        PMOS_CONTEXT       pMosCtx,
+        PMOS_RESOURCE      pInputResource,
+        PMOS_RESOURCE      pOutputResource,
+        uint32_t           copyWidth,
+        uint32_t           copyHeight,
+        uint32_t           copyInputOffset,
+        uint32_t           copyOutputOffset,
+        bool               bOutputCompressed);
+
     PLATFORM            platform;
 
     MediaLibvaCaps     *m_caps;
@@ -469,6 +507,7 @@ struct DDI_MEDIA_CONTEXT
     MEDIA_MUTEX_T    PutSurfaceRenderMutex;
     MEDIA_MUTEX_T    PutSurfaceSwapBufferMutex;
 #endif
+    bool apoMosEnabled;
 };
 
 static __inline PDDI_MEDIA_CONTEXT DdiMedia_GetMediaContext (VADriverContextP ctx)
