@@ -30,6 +30,102 @@
 #include "media_libva_caps_g10.h"
 #include "media_libva_caps_factory.h"
 
+const VAImageFormat m_supportedImageformatsG10[] =
+{   {VA_FOURCC_BGRA,           VA_LSB_FIRST,   32, 32, 0x0000ff00, 0x00ff0000, 0xff000000,  0x000000ff}, /* [31:0] B:G:R:A 8:8:8:8 little endian */
+    {VA_FOURCC_ARGB,           VA_LSB_FIRST,   32, 32, 0x00ff0000, 0x0000ff00, 0x000000ff,  0xff000000}, /* [31:0] A:R:G:B 8:8:8:8 little endian */
+    {VA_FOURCC_RGBA,           VA_LSB_FIRST,   32, 32, 0xff000000, 0x00ff0000, 0x0000ff00,  0x000000ff}, /* [31:0] R:G:B:A 8:8:8:8 little endian */
+    {VA_FOURCC_ABGR,           VA_LSB_FIRST,   32, 32, 0x000000ff, 0x0000ff00, 0x00ff0000,  0xff000000}, /* [31:0] A:B:G:R 8:8:8:8 little endian */
+    {VA_FOURCC_BGRX,           VA_LSB_FIRST,   32, 24, 0x0000ff00, 0x00ff0000, 0xff000000,  0},          /* [31:0] B:G:R:x 8:8:8:8 little endian */
+    {VA_FOURCC_XRGB,           VA_LSB_FIRST,   32, 24, 0x00ff0000, 0x0000ff00, 0x000000ff,  0},          /* [31:0] x:R:G:B 8:8:8:8 little endian */
+    {VA_FOURCC_RGBX,           VA_LSB_FIRST,   32, 24, 0xff000000, 0x00ff0000, 0x0000ff00,  0},          /* [31:0] R:G:B:x 8:8:8:8 little endian */
+    {VA_FOURCC_XBGR,           VA_LSB_FIRST,   32, 24, 0x000000ff, 0x0000ff00, 0x00ff0000,  0},          /* [31:0] x:B:G:R 8:8:8:8 little endian */
+    {VA_FOURCC_A2R10G10B10,    VA_LSB_FIRST,   32, 30, 0x3ff00000, 0x000ffc00, 0x000003ff,  0x30000000}, /* [31:0] A:R:G:B 2:10:10:10 little endian */
+    {VA_FOURCC_A2B10G10R10,    VA_LSB_FIRST,   32, 30, 0x000003ff, 0x000ffc00, 0x3ff00000,  0x30000000}, /* [31:0] A:B:G:R 2:10:10:10 little endian */
+    {VA_FOURCC_X2R10G10B10,    VA_LSB_FIRST,   32, 30, 0x3ff00000, 0x000ffc00, 0x000003ff,  0},          /* [31:0] X:R:G:B 2:10:10:10 little endian */
+    {VA_FOURCC_X2B10G10R10,    VA_LSB_FIRST,   32, 30, 0x000003ff, 0x000ffc00, 0x3ff00000,  0},          /* [31:0] X:B:G:R 2:10:10:10 little endian */
+    {VA_FOURCC_RGB565,         VA_LSB_FIRST,   16, 16, 0xf800,     0x07e0,     0x001f,      0},          /* [15:0] R:G:B 5:6:5 little endian */
+    {VA_FOURCC_AYUV,           VA_LSB_FIRST,   32, 0,0,0,0,0},
+    {VA_FOURCC_Y800,           VA_LSB_FIRST,   8,  0,0,0,0,0},
+    {VA_FOURCC_NV12,           VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_NV21,           VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_YUY2,           VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_UYVY,           VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_YV12,           VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_I420,           VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_411P,           VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_422H,           VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_422V,           VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_444P,           VA_LSB_FIRST,   24, 0,0,0,0,0},
+    {VA_FOURCC_IMC3,           VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_P010,           VA_LSB_FIRST,   24, 0,0,0,0,0}
+};
+
+VAStatus MediaLibvaCapsG10::QueryImageFormats(VAImageFormat *formatList, int32_t *numFormats)
+{
+    DDI_CHK_NULL(formatList, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
+    DDI_CHK_NULL(numFormats, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
+    int32_t num = 0;
+    uint32_t maxNum = GetImageFormatsMaxNum();
+
+    memset(formatList, 0,  sizeof(m_supportedImageformatsG10));
+    for (uint32_t idx = 0; idx < maxNum; idx++)
+    {
+        formatList[num].fourcc           = m_supportedImageformatsG10[idx].fourcc;
+        formatList[num].byte_order       = m_supportedImageformatsG10[idx].byte_order;
+        formatList[num].bits_per_pixel   = m_supportedImageformatsG10[idx].bits_per_pixel;
+        formatList[num].depth            = m_supportedImageformatsG10[idx].depth;
+        formatList[num].red_mask         = m_supportedImageformatsG10[idx].red_mask;
+        formatList[num].green_mask       = m_supportedImageformatsG10[idx].green_mask;
+        formatList[num].blue_mask        = m_supportedImageformatsG10[idx].blue_mask;
+        formatList[num].alpha_mask       = m_supportedImageformatsG10[idx].alpha_mask;
+        num++;
+    }
+    *numFormats = num;
+
+    return VA_STATUS_SUCCESS;
+}
+
+uint32_t MediaLibvaCapsG10::GetImageFormatsMaxNum()
+{
+    return sizeof(m_supportedImageformatsG10)/sizeof(m_supportedImageformatsG10[0]);
+}
+
+bool MediaLibvaCapsG10::IsImageSupported(uint32_t fourcc)
+{
+    uint32_t maxNum = GetImageFormatsMaxNum();
+    for (int32_t idx = 0; idx < maxNum; idx++)
+    {
+        if (m_supportedImageformatsG10[idx].fourcc == fourcc)
+        {
+            return true;
+        }
+    }
+    
+    return false;
+}
+
+VAStatus MediaLibvaCapsG10::PopulateColorMaskInfo(VAImageFormat *vaImgFmt)
+{
+    uint32_t maxNum = GetImageFormatsMaxNum();
+
+    DDI_CHK_NULL(vaImgFmt, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
+
+    for (int32_t idx = 0; idx < maxNum; idx++)
+    {
+        if (m_supportedImageformatsG10[idx].fourcc == vaImgFmt->fourcc)
+        {
+            vaImgFmt->red_mask   = m_supportedImageformatsG10[idx].red_mask;
+            vaImgFmt->green_mask = m_supportedImageformatsG10[idx].green_mask;
+            vaImgFmt->blue_mask  = m_supportedImageformatsG10[idx].blue_mask;
+            vaImgFmt->alpha_mask = m_supportedImageformatsG10[idx].alpha_mask;
+
+            return VA_STATUS_SUCCESS;
+        }
+    }
+
+    return VA_STATUS_ERROR_INVALID_IMAGE_FORMAT;
+}
+
 VAStatus MediaLibvaCapsG10::GetPlatformSpecificAttrib(VAProfile profile,
         VAEntrypoint entrypoint,
         VAConfigAttribType type,
@@ -37,6 +133,7 @@ VAStatus MediaLibvaCapsG10::GetPlatformSpecificAttrib(VAProfile profile,
 {
     DDI_CHK_NULL(value, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
     VAStatus status = VA_STATUS_SUCCESS;
+    *value = VA_ATTRIB_NOT_SUPPORTED;
     switch ((int)type)
     {
         case VAConfigAttribEncMaxRefFrames:
